<?php
/**
 * Medical Supplements Store functions and definitions
 *
 * @package Medical Supplements Store
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */

/* Theme Setup */
if ( ! function_exists( 'medical_supplements_store_setup' ) ) :

function medical_supplements_store_setup() {

	$GLOBALS['content_width'] = apply_filters( 'medical_supplements_store_content_width', 640 );

	load_theme_textdomain( 'medical-supplements-store', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'woocommerce' );
	add_theme_support( 'align-wide' );
	add_theme_support( 'wp-block-styles' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-logo', array(
		'height'      => 240,
		'width'       => 240,
		'flex-height' => true,
	) );
	add_image_size('medical-supplements-store-homepage-thumb',240,145,true);
	
       register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'medical-supplements-store' ),
	) );

	add_theme_support( 'custom-background', array(
		'default-color' => 'f1f1f1'
	) );

	add_theme_support ('html5', array (
        'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
    ) );

	add_theme_support('responsive-embeds');
	
	/*
	* Enable support for Post Formats.
	*
	* See: https://codex.wordpress.org/Post_Formats
	*/
	add_theme_support( 'post-formats', array('image','video','gallery','audio',) );

	/* Selective refresh for widgets */
	add_theme_support( 'customize-selective-refresh-widgets' );

	/* Starter Content */
	add_theme_support( 'starter-content', array(
		'widgets' => array(
			'sidebar-1' => array(
				'text_business_info',
				'search',
				'text_about',
			),
			'sidebar-2' => array(
				'text_business_info',
			),
			'sidebar-3' => array(
				'text_about',
				'search',
			),
			'footer-1' => array(
				'text_about',
			),
			'footer-2' => array(
				'archives',
			),
			'footer-3' => array(
				'text_business_info',
			),
			'footer-4' => array(
				'search',
			),
		),

		'posts' => array(
			'home',
			'about' => array(
				'thumbnail' => '{{image-espresso}}',
			),
			'contact' => array(
				'thumbnail' => '{{image-coffee}}',
			),
			'blog' => array(
				'thumbnail' => '{{image-coffee}}',
			),
		),

		'theme_mods' => array(
			'medical_supplements_store_world' => __('Worldwide Shipping', 'medical-supplements-store' ),
			'medical_supplements_store_free_shipping' => __('Free Delivery', 'medical-supplements-store' ),
			'' => '',
			'medical_supplements_store_facebook_url' => 'www.facebook.com',
			'medical_supplements_store_twitter_url' => 'www.twitter.com',
			'medical_supplements_store_insta_url' => 'www.instagram.com',
			'medical_supplements_store_linkdin_url' => 'www.linkedin.com',
			'medical_supplements_store_youtube_url' => 'www.youtube.com',
			'medical_supplements_store_footer_copy' => __('By ThemesCaliber', 'medical-supplements-store' )
		),

		'nav_menus' => array(
			'primary' => array(
				'name' => __( 'Primary Menu', 'medical-supplements-store' ),
				'items' => array(
					'page_home',
					'page_about',
					'page_blog',
					'page_contact',
				),
			),
		),
    ));

	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, icons, and column width.
	 */
	add_editor_style( array( 'css/editor-style.css', medical_supplements_store_font_url() ) );

	// Dashboard Theme Notification
	global $pagenow;
	
	if ( is_admin() && ('themes.php' == $pagenow) && isset( $_GET['activated'] ) ) {
		add_action( 'admin_notices', 'medical_supplements_store_activation_notice' );
	}	
}
endif;
add_action( 'after_setup_theme', 'medical_supplements_store_setup' );

// Dashboard Theme Notification
function medical_supplements_store_activation_notice() {
	echo '<div class="welcome-notice notice notice-success is-dismissible">';
		echo '<h2>'. esc_html__( 'Thank You!!!!!', 'medical-supplements-store' ) .'</h2>';
		echo '<p>'. esc_html__( 'Much grateful to you for choosing our medical supplement theme from themescaliber. we praise you for opting our services over others. we are obliged to invite you on our welcome page to render you with our outstanding services.', 'medical-supplements-store' ) .'</p>';
		echo '<p><a href="'. esc_url( admin_url( 'themes.php?page=medical_supplements_store_guide' ) ) .'" class="button button-primary">'. esc_html__( 'Click Here...', 'medical-supplements-store' ) .'</a></p>';
	echo '</div>';
}

/* Theme Widgets Setup */
function medical_supplements_store_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'medical-supplements-store' ),
		'description'   => __( 'Appears on blog page sidebar', 'medical-supplements-store' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s p-2 mb-4">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title pt-0">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Page Sidebar', 'medical-supplements-store' ),
		'description'   => __( 'Appears on page sidebar', 'medical-supplements-store' ),
		'id'            => 'sidebar-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s p-2 mb-4">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title pt-0">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Thid Column Sidebar', 'medical-supplements-store' ),
		'description'   => __( 'Appears on page sidebar', 'medical-supplements-store' ),
		'id'            => 'sidebar-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s p-2 mb-4">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title pt-0">',
		'after_title'   => '</h3>',
	) );

	//Footer widget areas
	$medical_supplements_store_widget_areas = get_theme_mod('medical_supplements_store_footer_widget_layout', '4');
	for ($i=1; $i<=$medical_supplements_store_widget_areas; $i++) {
		register_sidebar( array(
			'name'          => __( 'Footer Nav ', 'medical-supplements-store' ) . $i,
			'id'            => 'footer-' . $i,
			'description'   => '',
			'before_widget' => '<aside id="%1$s" class="widget %2$s py-2">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title py-2">',
			'after_title'   => '</h3>',
		) );
	}
	
}
add_action( 'widgets_init', 'medical_supplements_store_widgets_init' );

/* Theme Font URL */
function medical_supplements_store_font_url() {
	$font_url = '';
	$font_family = array();
	$font_family[] = 'ABeeZee:400,400i';
	$font_family[] = 'PT Sans:400,400i,700,700i';
	$font_family[] = 'PT Serif:400,400i,700,700i';
	$font_family[] = 'Roboto:100,100i,300,300i,400,400i,500,500i,700,700i,900,900i';
	$font_family[] = 'Roboto Condensed:300,300i,400,400i,700,700i';
	$font_family[] = 'Open Sans:300,300i,400,400i,600,600i,700,700i,800,800i';
	$font_family[] = 'Overpass:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'Montserrat:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'Playball:400';
	$font_family[] = 'Alegreya:400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'Julius Sans One';
	$font_family[] = 'Arsenal:400,400i,700,700i';
	$font_family[] = 'Sen:400,700,800';
	$font_family[] = 'Slabo';
	$font_family[] = 'Lato:100,100i,300,300i,400,400i,700,700i,900,900i';
	$font_family[] = 'Overpass Mono:300,400,500,600,700';
	$font_family[] = 'Source Sans Pro:200,200i,300,300i,400,400i,600,600i,700,700i,900,900i';
	$font_family[] = 'Raleway:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'Merriweather:300,300i,400,400i,700,700i,900,900i';
	$font_family[] = 'Droid Sans';
	$font_family[] = 'Rubik:300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'Lora:400,400i,500,500i,600,600i,700,700i';
	$font_family[] = 'Ubuntu:300,300i,400,400i,500,500i,700,700i';
	$font_family[] = 'Cabin:400,400i,500,500i,600,600i,700,700i';
	$font_family[] = 'Arimo:400,400i,500,500i,600,600i,700,700i';
	$font_family[] = 'Playfair Display:400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'Quicksand:300,400,500,600,700';
	$font_family[] = 'PadaukPadauk:400,700';
	$font_family[] = 'Muli';
	$font_family[] = 'Mulish:200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'Inconsolata:200,300,400,500,600,700,800,900';
	$font_family[] = 'Bitter:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'Pacifico';
	$font_family[] = 'Indie Flower';
	$font_family[] = 'VT323';
	$font_family[] = 'Dosis:200,300,400,500,600,700,800';
	$font_family[] = 'Frank Ruhl Libre:300,400,500,700,900';
	$font_family[] = 'Gabriela:400';
	$font_family[] = 'Fjalla One';
	$font_family[] = 'Oxygen:300,400,700';
	$font_family[] = 'Arvo:400,400i,700,700i';
	$font_family[] = 'Noto Serif:400,400i,700,700i';
	$font_family[] = 'Lobster';
	$font_family[] = 'Crimson Text:400,400i,600,600i,700,700i';
	$font_family[] = 'Cuprum:400,400i,500,500i,600,600i,700,700i';
	$font_family[] = 'Yanone Kaffeesatz:200,300,400,500,600,700';
	$font_family[] = 'Anton';
	$font_family[] = 'Libre Baskerville:400,400i,700';
	$font_family[] = 'Bree Serif';
	$font_family[] = 'Gloria Hallelujah';
	$font_family[] = 'Josefin Sans:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i';
	$font_family[] = 'Jost:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'Abril Fatface';
	$font_family[] = 'Varela Round';
	$font_family[] = 'Vampiro One';
	$font_family[] = 'Shadows Into Light';
	$font_family[] = 'Cuprum';
	$font_family[] = 'Rokkitt:100,200,300,400,500,600,700,800,900';
	$font_family[] = 'Vollkorn:400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'Francois One';
	$font_family[] = 'Orbitron:400,500,600,700,800,900';
	$font_family[] = 'Patua One';
	$font_family[] = 'Acme';
	$font_family[] = 'Allura:400';
	$font_family[] = 'Satisfy';
	$font_family[] = 'Josefin Slab:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i';
	$font_family[] = 'Quattrocento Sans:400,400i,700,700i';
	$font_family[] = 'Architects Daughter';
	$font_family[] = 'Archivo:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'Russo One';
	$font_family[] = 'Monda:400,700';
	$font_family[] = 'Righteous';
	$font_family[] = 'Saira:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'Lobster Two:400,400i,700,700i';
	$font_family[] = 'Hammersmith One';
	$font_family[] = 'Heebo:100,200,300,400,500,700,800,900';
	$font_family[] = 'Hind:300,400,500,600,700';
	$font_family[] = 'Courgette';
	$font_family[] = 'Permanent Marker';
	$font_family[] = 'Cherry Swash:400,700';
	$font_family[] = 'Cormorant Garamond:300,300i,400,400i,500,500i,600,600i,700,700i';
	$font_family[] = 'Poiret One';
	$font_family[] = 'Poppins:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'BenchNine:300,400,700';
	$font_family[] = 'Economica:400,400i,700,700i';
	$font_family[] = 'Fira Sans:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'Handlee';
	$font_family[] = 'Cardo:400,400i,700';
	$font_family[] = 'Alfa Slab One';
	$font_family[] = 'Averia Serif Libre:300,300i,400,400i,700,700i';
	$font_family[] = 'Cookie';
	$font_family[] = 'Chewy';
	$font_family[] = 'Great Vibes';
	$font_family[] = 'Coming Soon';
	$font_family[] = 'Philosopher:400,400i,700,700i';
	$font_family[] = 'Days One';
	$font_family[] = 'Kanit:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'Krub:200,200i,300,300i,400,400i,500,500i,600,600i,700,700i';
	$font_family[] = 'Shrikhand';
	$font_family[] = 'Spartan:100,200,300,400,500,600,700,800,900';
	$font_family[] = 'Tangerine:400,700';
	$font_family[] = 'Tangerine';
	$font_family[] = 'Trirong:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'IM Fell English SC';
	$font_family[] = 'Boogaloo';
	$font_family[] = 'Bangers';
	$font_family[] = 'Fredoka One';
	$font_family[] = 'Bad Script';
	$font_family[] = 'Volkhov:400,400i,700,700i';
	$font_family[] = 'Work Sans:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'Shadows Into Light Two';
	$font_family[] = 'Marck Script';
	$font_family[] = 'Sacramento';
	$font_family[] = 'Unica One';
	$font_family[] = 'Exo:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'ZCOOL XiaoWei';

	$query_args = array(
		'family'	=> rawurlencode(implode('|',$font_family)),
	);
	$font_url = add_query_arg($query_args,'//fonts.googleapis.com/css');
	return $font_url;
	$contents = wptt_get_webfont_url( esc_url_raw( $fonts_url ) );
}

/* Theme enqueue scripts */
function medical_supplements_store_scripts() {
	wp_enqueue_style( 'medical-supplements-store-font', medical_supplements_store_font_url(), array() );	
	wp_enqueue_style( 'bootstrap-css', esc_url(get_template_directory_uri()).'/css/bootstrap.css' );
	wp_enqueue_style( 'medical-supplements-store-basic-style', get_stylesheet_uri() );
	wp_style_add_data( 'medical-supplements-store-style', 'rtl', 'replace' );
	wp_enqueue_style( 'font-awesome-css', esc_url(get_template_directory_uri()).'/css/fontawesome-all.css' );
	wp_enqueue_style( 'medical-supplements-store-block-style', esc_url(get_template_directory_uri()).'/css/block-style.css' );	

	// Paragraph
    $medical_supplements_store_paragraph_color = get_theme_mod('medical_supplements_store_paragraph_color', '');
    $medical_supplements_store_paragraph_font_family = get_theme_mod('medical_supplements_store_paragraph_font_family', '');
    $medical_supplements_store_paragraph_font_size = get_theme_mod('medical_supplements_store_paragraph_font_size', '');
	// "a" tag
	$medical_supplements_store_atag_color = get_theme_mod('medical_supplements_store_atag_color', '');
    $medical_supplements_store_atag_font_family = get_theme_mod('medical_supplements_store_atag_font_family', '');
	// "li" tag
	$medical_supplements_store_li_color = get_theme_mod('medical_supplements_store_li_color', '');
    $medical_supplements_store_li_font_family = get_theme_mod('medical_supplements_store_li_font_family', '');
	// H1
	$medical_supplements_store_h1_color = get_theme_mod('medical_supplements_store_h1_color', '');
    $medical_supplements_store_h1_font_family = get_theme_mod('medical_supplements_store_h1_font_family', '');
    $medical_supplements_store_h1_font_size = get_theme_mod('medical_supplements_store_h1_font_size', '');
	// H2
	$medical_supplements_store_h2_color = get_theme_mod('medical_supplements_store_h2_color', '');
    $medical_supplements_store_h2_font_family = get_theme_mod('medical_supplements_store_h2_font_family', '');
    $medical_supplements_store_h2_font_size = get_theme_mod('medical_supplements_store_h2_font_size', '');
	// H3
	$medical_supplements_store_h3_color = get_theme_mod('medical_supplements_store_h3_color', '');
    $medical_supplements_store_h3_font_family = get_theme_mod('medical_supplements_store_h3_font_family', '');
    $medical_supplements_store_h3_font_size = get_theme_mod('medical_supplements_store_h3_font_size', '');
	// H4
	$medical_supplements_store_h4_color = get_theme_mod('medical_supplements_store_h4_color', '');
    $medical_supplements_store_h4_font_family = get_theme_mod('medical_supplements_store_h4_font_family', '');
    $medical_supplements_store_h4_font_size = get_theme_mod('medical_supplements_store_h4_font_size', '');
	// H5
	$medical_supplements_store_h5_color = get_theme_mod('medical_supplements_store_h5_color', '');
    $medical_supplements_store_h5_font_family = get_theme_mod('medical_supplements_store_h5_font_family', '');
    $medical_supplements_store_h5_font_size = get_theme_mod('medical_supplements_store_h5_font_size', '');
	// H6
	$medical_supplements_store_h6_color = get_theme_mod('medical_supplements_store_h6_color', '');
    $medical_supplements_store_h6_font_family = get_theme_mod('medical_supplements_store_h6_font_family', '');
    $medical_supplements_store_h6_font_size = get_theme_mod('medical_supplements_store_h6_font_size', '');
    $medical_supplements_store_theme_color = get_theme_mod('medical_supplements_store_theme_color', '');

	$medical_supplements_store_custom_css ='
		p,span{
		    color:'.esc_attr($medical_supplements_store_paragraph_color).'!important;
		    font-family: '.esc_attr($medical_supplements_store_paragraph_font_family).';
		    font-size: '.esc_attr($medical_supplements_store_paragraph_font_size).';
		}
		a{
		    color:'.esc_attr($medical_supplements_store_atag_color).'!important;
		    font-family: '.esc_attr($medical_supplements_store_atag_font_family).';
		}
		li{
		    color:'.esc_attr($medical_supplements_store_li_color).'!important;
		    font-family: '.esc_attr($medical_supplements_store_li_font_family).';
		}
		h1{
		    color:'.esc_attr($medical_supplements_store_h1_color).'!important;
		    font-family: '.esc_attr($medical_supplements_store_h1_font_family).'!important;
		    font-size: '.esc_attr($medical_supplements_store_h1_font_size).'!important;
		}
		h2{
		    color:'.esc_attr($medical_supplements_store_h2_color).'!important;
		    font-family: '.esc_attr($medical_supplements_store_h2_font_family).'!important;
		    font-size: '.esc_attr($medical_supplements_store_h2_font_size).'!important;
		}
		h3{
		    color:'.esc_attr($medical_supplements_store_h3_color).'!important;
		    font-family: '.esc_attr($medical_supplements_store_h3_font_family).'!important;
		    font-size: '.esc_attr($medical_supplements_store_h3_font_size).'!important;
		}
		h4{
		    color:'.esc_attr($medical_supplements_store_h4_color).'!important;
		    font-family: '.esc_attr($medical_supplements_store_h4_font_family).'!important;
		    font-size: '.esc_attr($medical_supplements_store_h4_font_size).'!important;
		}
		h5{
		    color:'.esc_attr($medical_supplements_store_h5_color).'!important;
		    font-family: '.esc_attr($medical_supplements_store_h5_font_family).'!important;
		    font-size: '.esc_attr($medical_supplements_store_h5_font_size).'!important;
		}
		h6{
		    color:'.esc_attr($medical_supplements_store_h6_color).'!important;
		    font-family: '.esc_attr($medical_supplements_store_h6_font_family).'!important;
		    font-size: '.esc_attr($medical_supplements_store_h6_font_size).'!important;
		}
		.woocommerce span.onsale{
		    background-color:'.esc_attr($medical_supplements_store_theme_color).'!important;
		}
		#custom-page-services,.primary-navigation a:hover,.primary-navigation ul ul a,.tags a:hover, span.onsale, #our-products .woocommerce a.button:hover, .woocommerce ul.products li.product .button:hover, .woocommerce #respond input#submit.alt:hover, .woocommerce a.button.alt:hover, .woocommerce button.button.alt:hover, .woocommerce input.button.alt:hover button.single_add_to_cart_button.button.alt:hover, .footertown th, #footer, .footertown .tagcloud a:hover, .footertown input[type="submit"], input[type="submit"], #header .nav .current_page_item a, #sidebar input[type="submit"], #sidebar th, nav.woocommerce-MyAccount-navigation ul li,.woocommerce #respond input#submit, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button, #sidebar .tagcloud a:hover, .woocommerce-product-search button[type="submit"], .service-btn a, .pagination .current, .page-links .current, .pagination a:hover, .page-links a:hover, .woocommerce .widget_price_filter .ui-slider .ui-slider-range, .woocommerce .widget_price_filter .ui-slider .ui-slider-handle, #comments a.comment-reply-link, .page-content .read-moresec a.button{
		    background-color:'.esc_attr($medical_supplements_store_theme_color).';
		}
		.logo h1 a,.tags a,span.post-title,a,code,.entry-content a,.logo p a, .logo p, span.woocommerce-Price-amount.amount,.topbox i:hover,  #sidebar td#prev a, #sidebar caption, #sidebar ul li a:hover,.content-aa a, .product_meta a, .product_meta a, .entry-content a, #sidebar .textwidget a, .scrollup, .scrollup:focus, .scrollup:hover, .footertown .widget ul li a:hover, a.button, .metabox .entry-author a:hover,.metabox .entry-date a:hover, .copyright a:hover{
		    color:'.esc_attr($medical_supplements_store_theme_color).';
		}
		
		@media screen and (max-width: 1000px){
			.primary-navigation ul ul a:hover, .primary-navigation ul li a:hover{
			    color:'.esc_attr($medical_supplements_store_theme_color).'!important;
			}
			.sidebar, .side-menu{
			    background-color:'.esc_attr($medical_supplements_store_theme_color).'!important;
			}
		}
		.services-box:hover,.tags a{
		    border-color:'.esc_attr($medical_supplements_store_theme_color).';
		}
	';

	wp_add_inline_style( 'medical-supplements-store-basic-style',$medical_supplements_store_custom_css );

	require get_parent_theme_file_path( '/tc-style.php' );
	wp_add_inline_style( 'medical-supplements-store-basic-style',$medical_supplements_store_custom_css );

	wp_enqueue_script( 'bootstrap-js', esc_url(get_template_directory_uri()) . '/js/bootstrap.js', array('jquery') );
	wp_enqueue_script( 'medical-supplements-store-customscripts-jquery', esc_url(get_template_directory_uri()) . '/js/custom.js', array('jquery') );
	wp_enqueue_script( 'jquery-superfish', esc_url(get_template_directory_uri()) . '/js/jquery.superfish.js', array('jquery') ,'',true);
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'medical_supplements_store_scripts' );

function medical_supplements_store_sanitize_dropdown_pages( $page_id, $setting ) {
  // Ensure $input is an absolute integer.
  $page_id = absint( $page_id );
  // If $page_id is an ID of a published page, return it; otherwise, return the default.
  return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
}

// Change number or products per row to 3
add_filter('loop_shop_columns', 'medical_supplements_store_loop_columns');
if (!function_exists('medical_supplements_store_loop_columns')) {
	function medical_supplements_store_loop_columns() {
		$columns = get_theme_mod( 'medical_supplements_store_products_per_row', 3 );
		return $columns; // 3 products per row
	}
}

//Change number of products that are displayed per page (shop page)
add_filter( 'loop_shop_per_page', 'medical_supplements_store_shop_per_page', 9 );
function medical_supplements_store_shop_per_page( $cols ) {
  	$cols = get_theme_mod( 'medical_supplements_store_product_per_page', 9 );
	return $cols;
}

/* Excerpt Limit Begin */
function medical_supplements_store_string_limit_words($string, $word_limit) {
	$words = explode(' ', $string, ($word_limit + 1));
	if(count($words) > $word_limit)
	array_pop($words);
	return implode(' ', $words);
}

/*radio button sanitization*/
function medical_supplements_store_sanitize_choices( $input, $setting ) {
    global $wp_customize; 
    $control = $wp_customize->get_control( $setting->id ); 
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

// URL DEFINES
define('MEDICAL_SUPPLEMENTS_STORE_FREE_THEME_DOC',__('https://themescaliber.com/demo/doc/free-medical-supplements/', 'medical-supplements-store'));
define('MEDICAL_SUPPLEMENTS_STORE_SUPPORT',__('https://wordpress.org/support/theme/medical-supplements-store', 'medical-supplements-store'));
define('MEDICAL_SUPPLEMENTS_STORE_REVIEW',__('https://wordpress.org/support/theme/medical-supplements-store/reviews/', 'medical-supplements-store'));
define('MEDICAL_SUPPLEMENTS_STORE_BUY_NOW',__('https://www.themescaliber.com/themes/premium-medical-supplements-wordpress-theme', 'medical-supplements-store'));
define('MEDICAL_SUPPLEMENTS_STORE_LIVE_DEMO',__('https://www.themescaliber.com/medical-supplements-store-pro', 'medical-supplements-store'));
define('MEDICAL_SUPPLEMENTS_STORE_PRO_DOC',__('https://www.themescaliber.com/demo/doc/medical-supplements-store-pro/', 'medical-supplements-store'));
define('MEDICAL_SUPPLEMENTS_STORE_CHILD_THEME',__('https://developer.wordpress.org/themes/advanced-topics/child-themes/', 'medical-supplements-store'));

define('MEDICAL_SUPPLEMENTS_STORE_SITE_URL',__('https://www.themescaliber.com/themes/free-medical-supplements-wordpress-theme/', 'medical-supplements-store'));
function medical_supplements_store_credit_link() {
    echo "<a href=".esc_url(MEDICAL_SUPPLEMENTS_STORE_SITE_URL)." target='_blank'>".esc_html__('Medical Supplements WordPress Theme','medical-supplements-store')."</a>";
}

function medical_supplements_store_sanitize_checkbox( $input ) {
	// Boolean check 
	return ( ( isset( $input ) && true == $input ) ? true : false );
}

function medical_supplements_store_sanitize_float( $input ) {
    return filter_var($input, FILTER_SANITIZE_NUMBER_FLOAT, FILTER_FLAG_ALLOW_FRACTION);
}

/** Posts navigation. */
if ( ! function_exists( 'medical_supplements_store_post_navigation' ) ) {
	function medical_supplements_store_post_navigation() {
		$medical_supplements_store_pagination_type = get_theme_mod( 'medical_supplements_store_post_navigation_type', 'numbers' );
		if ( $medical_supplements_store_pagination_type == 'numbers' ) {
			the_posts_pagination();
		} else {
			the_posts_navigation( array(
	            'prev_text'          => __( 'Previous page', 'medical-supplements-store' ),
	            'next_text'          => __( 'Next page', 'medical-supplements-store' ),
	            'before_page_number' => '<span class="meta-nav screen-reader-text">' . __( 'Page', 'medical-supplements-store' ) . ' </span>',
	        ) );
		}
	}
}

/* Custom template tags for this theme. */
require get_template_directory() . '/inc/template-tags.php';

/* Implement the Custom Header feature. */
require get_template_directory() . '/inc/custom-header.php';

/* Customizer additions. */
require get_template_directory() . '/inc/customizer.php';

/* Implement the About theme page */
require get_template_directory() . '/inc/dashboard/getstart.php';

/* Webfonts */
require get_template_directory() . '/wptt-webfont-loader.php';