<?php
/**
 * Medical Supplements Store Theme Customizer
 *
 * @package Medical Supplements Store
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function medical_supplements_store_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . '/inc/icon-changer.php' );

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';

	$wp_customize->selective_refresh->add_partial(
		'blogname',
		array(
			'selector'        => '.site-title a',
			'render_callback' => 'medical_supplements_store_customize_partial_blogname',
		)
	);
	$wp_customize->selective_refresh->add_partial(
		'blogdescription',
		array(
			'selector'        => '.site-description',
			'render_callback' => 'medical_supplements_store_customize_partial_blogdescription',
		)
	);
	
	/* Custom panel type - used for multiple levels of panels */
	if ( class_exists( 'WP_Customize_Panel' ) ) {

		/**
		 * Class Medical_Supplements_Store_WP_Customize_Panel
		 */
		class Medical_Supplements_Store_WP_Customize_Panel extends WP_Customize_Panel {

			/**
			 * Panel
			 *
			 * @var $panel string Panel
			 */
			public $panel;

			/**
			 * Panel type
			 *
			 * @var $type string Panel type.
			 */
			public $type = 'medical_supplements_store_panel';

			/**
			 * Form the json
			 */
			public function json() {

				$array                   = wp_array_slice_assoc(
					(array) $this, array(
						'id',
						'description',
						'priority',
						'type',
						'panel',
					)
				);
				$array['title']          = html_entity_decode( $this->title, ENT_QUOTES, get_bloginfo( 'charset' ) );
				$array['content']        = $this->get_content();
				$array['active']         = $this->active();
				$array['instanceNumber'] = $this->instance_number;

				return $array;

			}

		}

	}

	$wp_customize->register_panel_type( 'Medical_Supplements_Store_WP_Customize_Panel' );

	/**
	 * Upsells
	 */
	load_template( trailingslashit( get_template_directory() ) . 'inc/class-customizer-theme-info-control.php' );

	$wp_customize->add_section('medical_supplements_store_theme_info_main_section', array(
		'title'    => __( 'View PRO version', 'medical-supplements-store' ),
		'priority' => 1,
	) );
	$wp_customize->add_setting('medical_supplements_store_theme_info_main_control', array(
		'sanitize_callback' => 'esc_html',
	));

	$wp_customize->add_control(new Medical_Supplements_Store_Theme_Info($wp_customize, 'medical_supplements_store_theme_info_main_control', array(
		'section'     => 'medical_supplements_store_theme_info_main_section',
		'priority'    => 100,
		'options'     => array(
			esc_html__( 'Enable-Disable options on every section', 'medical-supplements-store' ),
			esc_html__( 'Background Color & Image Option', 'medical-supplements-store' ),
			esc_html__( '100+ Font Family Options', 'medical-supplements-store' ),
			esc_html__( 'Advanced Color options', 'medical-supplements-store' ),
			esc_html__( 'Translation ready', 'medical-supplements-store' ),
			esc_html__( 'Gallery, Banner, Post Type Plugin Functionality', 'medical-supplements-store' ),
			esc_html__( 'Integrated Google map', 'medical-supplements-store' ),
			esc_html__( '1 Year Free Support', 'medical-supplements-store' ),
		),
		'button_url'  => esc_url( 'https://www.themescaliber.com/themes/premium-medical-supplements-wordpress-theme' ),
		'button_text' => esc_html__( 'View PRO version', 'medical-supplements-store' ),
	)));

	$medical_supplements_store_font_array = array(
        '' =>'No Fonts',
        'Abril Fatface' => 'Abril Fatface',
        'Acme' =>'Acme', 
        'Anton' => 'Anton', 
        'Architects Daughter' =>'Architects Daughter',
        'Arimo' => 'Arimo', 
        'Arsenal' =>'Arsenal',
        'Arvo' =>'Arvo',
        'Alegreya' =>'Alegreya',
        'Alfa Slab One' =>'Alfa Slab One',
        'Averia Serif Libre' =>'Averia Serif Libre', 
        'Bangers' =>'Bangers', 
        'Boogaloo' =>'Boogaloo', 
        'Bad Script' =>'Bad Script',
        'Bitter' =>'Bitter', 
        'Bree Serif' =>'Bree Serif', 
        'BenchNine' =>'BenchNine',
        'Cabin' =>'Cabin',
        'Cardo' =>'Cardo', 
        'Courgette' =>'Courgette', 
        'Cherry Swash' =>'Cherry Swash',
        'Cormorant Garamond' =>'Cormorant Garamond', 
        'Crimson Text' =>'Crimson Text',
        'Cuprum' =>'Cuprum', 
        'Cookie' =>'Cookie',
        'Chewy' =>'Chewy',
        'Days One' =>'Days One',
        'Dosis' =>'Dosis',
        'Droid Sans' =>'Droid Sans', 
        'Economica' =>'Economica', 
        'Fredoka One' =>'Fredoka One',
        'Fjalla One' =>'Fjalla One',
        'Francois One' =>'Francois One', 
        'Frank Ruhl Libre' => 'Frank Ruhl Libre', 
        'Gloria Hallelujah' =>'Gloria Hallelujah',
        'Great Vibes' =>'Great Vibes', 
        'Handlee' =>'Handlee', 
        'Hammersmith One' =>'Hammersmith One',
        'Inconsolata' =>'Inconsolata',
        'Indie Flower' =>'Indie Flower', 
        'IM Fell English SC' =>'IM Fell English SC',
        'Julius Sans One' =>'Julius Sans One',
        'Josefin Slab' =>'Josefin Slab',
        'Josefin Sans' =>'Josefin Sans',
        'Kanit' =>'Kanit',
        'Lobster' =>'Lobster',
        'Lato' => 'Lato',
        'Lora' =>'Lora', 
        'Libre Baskerville' =>'Libre Baskerville',
        'Lobster Two' => 'Lobster Two',
        'Merriweather' =>'Merriweather',
        'Monda' =>'Monda',
        'Montserrat' =>'Montserrat',
        'Muli' =>'Muli',
        'Marck Script' =>'Marck Script',
        'Noto Serif' =>'Noto Serif',
        'Open Sans' =>'Open Sans',
        'Overpass' => 'Overpass', 
        'Overpass Mono' =>'Overpass Mono',
        'Oxygen' =>'Oxygen',
        'Orbitron' =>'Orbitron',
        'Patua One' =>'Patua One',
        'Pacifico' =>'Pacifico',
        'Padauk' =>'Padauk',
        'Playball' =>'Playball',
        'Playfair Display' =>'Playfair Display',
        'PT Sans' =>'PT Sans',
        'Philosopher' =>'Philosopher',
        'Permanent Marker' =>'Permanent Marker',
        'Poiret One' =>'Poiret One',
        'Quicksand' =>'Quicksand',
        'Quattrocento Sans' =>'Quattrocento Sans',
        'Raleway' =>'Raleway',
        'Rubik' =>'Rubik',
        'Rokkitt' =>'Rokkitt',
        'Russo One' => 'Russo One', 
        'Righteous' =>'Righteous', 
        'Slabo' =>'Slabo', 
        'Source Sans Pro' =>'Source Sans Pro',
        'Shadows Into Light Two' =>'Shadows Into Light Two',
        'Shadows Into Light' =>  'Shadows Into Light',
        'Sacramento' =>'Sacramento',
        'Shrikhand' =>'Shrikhand',
        'Tangerine' => 'Tangerine',
        'Ubuntu' =>'Ubuntu',
        'VT323' =>'VT323',
        'Varela Round' =>'Varela Round',
        'Vampiro One' =>'Vampiro One',
        'Vollkorn' => 'Vollkorn',
        'Volkhov' =>'Volkhov',
        'Kavoon' =>'Kavoon',
        'Exo' =>'Exo',
        'Yanone Kaffeesatz' =>'Yanone Kaffeesatz'
    );

	//add home page setting pannel
	$wp_customize->add_panel( 'medical_supplements_store_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'Theme Settings', 'medical-supplements-store' ),
	    'description' => __( 'Description of what this panel does.', 'medical-supplements-store' )
	) );

	//Color / Font Pallete
	$wp_customize->add_section( 'medical_supplements_store_typography', array(
    	'title'      => __( 'Color / Font Pallete', 'medical-supplements-store' ),
		'priority'   => 30,
		'panel' => 'medical_supplements_store_panel_id'
	) );

	// Add the Theme Color Option section.
	$wp_customize->add_setting( 'medical_supplements_store_theme_color', array(
	    'default' => '',
	    'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'medical_supplements_store_theme_color', array(
  		'label' => __('Theme Color Option','medical-supplements-store'),
	    'section' => 'medical_supplements_store_typography',
	    'settings' => 'medical_supplements_store_theme_color',
  	)));
	
	// This is Paragraph Color picker setting
	$wp_customize->add_setting( 'medical_supplements_store_paragraph_color', array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'medical_supplements_store_paragraph_color', array(
		'label' => __('Paragraph Color', 'medical-supplements-store'),
		'section' => 'medical_supplements_store_typography',
		'settings' => 'medical_supplements_store_paragraph_color',
	)));

	//This is Paragraph FontFamily picker setting
	$wp_customize->add_setting('medical_supplements_store_paragraph_font_family',array(
	  'default' => '',
	  'capability' => 'edit_theme_options',
	  'sanitize_callback' => 'medical_supplements_store_sanitize_choices'
	));
	$wp_customize->add_control(
	    'medical_supplements_store_paragraph_font_family', array(
	    'section'  => 'medical_supplements_store_typography',
	    'label'    => __( 'Paragraph Fonts','medical-supplements-store'),
	    'type'     => 'select',
	    'choices'  => $medical_supplements_store_font_array,
	));

	$wp_customize->add_setting('medical_supplements_store_paragraph_font_size',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('medical_supplements_store_paragraph_font_size',array(
		'label'	=> __('Paragraph Font Size','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_typography',
		'setting'	=> 'medical_supplements_store_paragraph_font_size',
		'type'	=> 'text'
	));

	// This is "a" Tag Color picker setting
	$wp_customize->add_setting( 'medical_supplements_store_atag_color', array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'medical_supplements_store_atag_color', array(
		'label' => __('"a" Tag Color', 'medical-supplements-store'),
		'section' => 'medical_supplements_store_typography',
		'settings' => 'medical_supplements_store_atag_color',
	)));

	//This is "a" Tag FontFamily picker setting
	$wp_customize->add_setting('medical_supplements_store_atag_font_family',array(
	  'default' => '',
	  'capability' => 'edit_theme_options',
	  'sanitize_callback' => 'medical_supplements_store_sanitize_choices'
	));
	$wp_customize->add_control(
	    'medical_supplements_store_atag_font_family', array(
	    'section'  => 'medical_supplements_store_typography',
	    'label'    => __( '"a" Tag Fonts','medical-supplements-store'),
	    'type'     => 'select',
	    'choices'  => $medical_supplements_store_font_array,
	));

	// This is "a" Tag Color picker setting
	$wp_customize->add_setting( 'medical_supplements_store_li_color', array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'medical_supplements_store_li_color', array(
		'label' => __('"li" Tag Color', 'medical-supplements-store'),
		'section' => 'medical_supplements_store_typography',
		'settings' => 'medical_supplements_store_li_color',
	)));

	//This is "li" Tag FontFamily picker setting
	$wp_customize->add_setting('medical_supplements_store_li_font_family',array(
	  'default' => '',
	  'capability' => 'edit_theme_options',
	  'sanitize_callback' => 'medical_supplements_store_sanitize_choices'
	));
	$wp_customize->add_control(
	    'medical_supplements_store_li_font_family', array(
	    'section'  => 'medical_supplements_store_typography',
	    'label'    => __( '"li" Tag Fonts','medical-supplements-store'),
	    'type'     => 'select',
	    'choices'  => $medical_supplements_store_font_array,
	));

	// This is H1 Color picker setting
	$wp_customize->add_setting( 'medical_supplements_store_h1_color', array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'medical_supplements_store_h1_color', array(
		'label' => __('H1 Color', 'medical-supplements-store'),
		'section' => 'medical_supplements_store_typography',
		'settings' => 'medical_supplements_store_h1_color',
	)));

	//This is H1 FontFamily picker setting
	$wp_customize->add_setting('medical_supplements_store_h1_font_family',array(
	  'default' => '',
	  'capability' => 'edit_theme_options',
	  'sanitize_callback' => 'medical_supplements_store_sanitize_choices'
	));
	$wp_customize->add_control(
	    'medical_supplements_store_h1_font_family', array(
	    'section'  => 'medical_supplements_store_typography',
	    'label'    => __( 'H1 Fonts','medical-supplements-store'),
	    'type'     => 'select',
	    'choices'  => $medical_supplements_store_font_array,
	));

	//This is H1 FontSize setting
	$wp_customize->add_setting('medical_supplements_store_h1_font_size',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('medical_supplements_store_h1_font_size',array(
		'label'	=> __('H1 Font Size','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_typography',
		'setting'	=> 'medical_supplements_store_h1_font_size',
		'type'	=> 'text'
	));

	// This is H2 Color picker setting
	$wp_customize->add_setting( 'medical_supplements_store_h2_color', array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'medical_supplements_store_h2_color', array(
		'label' => __('h2 Color', 'medical-supplements-store'),
		'section' => 'medical_supplements_store_typography',
		'settings' => 'medical_supplements_store_h2_color',
	)));

	//This is H2 FontFamily picker setting
	$wp_customize->add_setting('medical_supplements_store_h2_font_family',array(
	  'default' => '',
	  'capability' => 'edit_theme_options',
	  'sanitize_callback' => 'medical_supplements_store_sanitize_choices'
	));
	$wp_customize->add_control(
	    'medical_supplements_store_h2_font_family', array(
	    'section'  => 'medical_supplements_store_typography',
	    'label'    => __( 'h2 Fonts','medical-supplements-store'),
	    'type'     => 'select',
	    'choices'  => $medical_supplements_store_font_array,
	));

	//This is H2 FontSize setting
	$wp_customize->add_setting('medical_supplements_store_h2_font_size',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('medical_supplements_store_h2_font_size',array(
		'label'	=> __('h2 Font Size','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_typography',
		'setting'	=> 'medical_supplements_store_h2_font_size',
		'type'	=> 'text'
	));

	// This is H3 Color picker setting
	$wp_customize->add_setting( 'medical_supplements_store_h3_color', array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'medical_supplements_store_h3_color', array(
		'label' => __('h3 Color', 'medical-supplements-store'),
		'section' => 'medical_supplements_store_typography',
		'settings' => 'medical_supplements_store_h3_color',
	)));

	//This is H3 FontFamily picker setting
	$wp_customize->add_setting('medical_supplements_store_h3_font_family',array(
	  'default' => '',
	  'capability' => 'edit_theme_options',
	  'sanitize_callback' => 'medical_supplements_store_sanitize_choices'
	));
	$wp_customize->add_control(
	    'medical_supplements_store_h3_font_family', array(
	    'section'  => 'medical_supplements_store_typography',
	    'label'    => __( 'h3 Fonts','medical-supplements-store'),
	    'type'     => 'select',
	    'choices'  => $medical_supplements_store_font_array,
	));

	//This is H3 FontSize setting
	$wp_customize->add_setting('medical_supplements_store_h3_font_size',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('medical_supplements_store_h3_font_size',array(
		'label'	=> __('h3 Font Size','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_typography',
		'setting'	=> 'medical_supplements_store_h3_font_size',
		'type'	=> 'text'
	));

	// This is H4 Color picker setting
	$wp_customize->add_setting( 'medical_supplements_store_h4_color', array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'medical_supplements_store_h4_color', array(
		'label' => __('h4 Color', 'medical-supplements-store'),
		'section' => 'medical_supplements_store_typography',
		'settings' => 'medical_supplements_store_h4_color',
	)));

	//This is H4 FontFamily picker setting
	$wp_customize->add_setting('medical_supplements_store_h4_font_family',array(
	  'default' => '',
	  'capability' => 'edit_theme_options',
	  'sanitize_callback' => 'medical_supplements_store_sanitize_choices'
	));
	$wp_customize->add_control(
	    'medical_supplements_store_h4_font_family', array(
	    'section'  => 'medical_supplements_store_typography',
	    'label'    => __( 'h4 Fonts','medical-supplements-store'),
	    'type'     => 'select',
	    'choices'  => $medical_supplements_store_font_array,
	));

	//This is H4 FontSize setting
	$wp_customize->add_setting('medical_supplements_store_h4_font_size',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('medical_supplements_store_h4_font_size',array(
		'label'	=> __('h4 Font Size','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_typography',
		'setting'	=> 'medical_supplements_store_h4_font_size',
		'type'	=> 'text'
	));

	// This is H5 Color picker setting
	$wp_customize->add_setting( 'medical_supplements_store_h5_color', array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'medical_supplements_store_h5_color', array(
		'label' => __('h5 Color', 'medical-supplements-store'),
		'section' => 'medical_supplements_store_typography',
		'settings' => 'medical_supplements_store_h5_color',
	)));

	//This is H5 FontFamily picker setting
	$wp_customize->add_setting('medical_supplements_store_h5_font_family',array(
	  'default' => '',
	  'capability' => 'edit_theme_options',
	  'sanitize_callback' => 'medical_supplements_store_sanitize_choices'
	));
	$wp_customize->add_control(
	    'medical_supplements_store_h5_font_family', array(
	    'section'  => 'medical_supplements_store_typography',
	    'label'    => __( 'h5 Fonts','medical-supplements-store'),
	    'type'     => 'select',
	    'choices'  => $medical_supplements_store_font_array,
	));

	//This is H5 FontSize setting
	$wp_customize->add_setting('medical_supplements_store_h5_font_size',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('medical_supplements_store_h5_font_size',array(
		'label'	=> __('h5 Font Size','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_typography',
		'setting'	=> 'medical_supplements_store_h5_font_size',
		'type'	=> 'text'
	));

	// This is H6 Color picker setting
	$wp_customize->add_setting( 'medical_supplements_store_h6_color', array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'medical_supplements_store_h6_color', array(
		'label' => __('h6 Color', 'medical-supplements-store'),
		'section' => 'medical_supplements_store_typography',
		'settings' => 'medical_supplements_store_h6_color',
	)));

	//This is H6 FontFamily picker setting
	$wp_customize->add_setting('medical_supplements_store_h6_font_family',array(
	  'default' => '',
	  'capability' => 'edit_theme_options',
	  'sanitize_callback' => 'medical_supplements_store_sanitize_choices'
	));
	$wp_customize->add_control(
	    'medical_supplements_store_h6_font_family', array(
	    'section'  => 'medical_supplements_store_typography',
	    'label'    => __( 'h6 Fonts','medical-supplements-store'),
	    'type'     => 'select',
	    'choices'  => $medical_supplements_store_font_array,
	));

	//This is H6 FontSize setting
	$wp_customize->add_setting('medical_supplements_store_h6_font_size',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('medical_supplements_store_h6_font_size',array(
		'label'	=> __('h6 Font Size','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_typography',
		'setting'	=> 'medical_supplements_store_h6_font_size',
		'type'	=> 'text'
	));

	//Layouts
	$wp_customize->add_section( 'medical_supplements_store_left_right', array(
    	'title'      => __( 'Theme Layout Settings', 'medical-supplements-store' ),
		'priority'   => 30,
		'panel' => 'medical_supplements_store_panel_id'
	) );

	// Preloader
	$wp_customize->add_setting( 'medical_supplements_store_preloader_hide',array(
		'default' => true,
      	'sanitize_callback'	=> 'medical_supplements_store_sanitize_checkbox'
    ) );
    $wp_customize->add_control('medical_supplements_store_preloader_hide',array(
    	'type' => 'checkbox',
        'label' => __( 'Show / Hide Preloader','medical-supplements-store' ),
        'section' => 'medical_supplements_store_left_right'
    ));

    $wp_customize->add_setting('medical_supplements_store_preloader_type',array(
        'default'   => 'center-square',
        'sanitize_callback' => 'medical_supplements_store_sanitize_choices'
	));
	$wp_customize->add_control( 'medical_supplements_store_preloader_type', array(
		'label' => __( 'Preloader Type','medical-supplements-store' ),
		'section' => 'medical_supplements_store_left_right',
		'type'  => 'select',
		'settings' => 'medical_supplements_store_preloader_type',
		'choices' => array(
		    'center-square' => __('Center Square','medical-supplements-store'),
		    'chasing-square' => __('Chasing Square','medical-supplements-store'),
	    ),
	));

	$wp_customize->add_setting( 'medical_supplements_store_preloader_color', array(
	    'default' => '#333333',
	    'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'medical_supplements_store_preloader_color', array(
  		'label' => 'Preloader Color',
	    'section' => 'medical_supplements_store_left_right',
	    'settings' => 'medical_supplements_store_preloader_color',
  	)));

  	$wp_customize->add_setting( 'medical_supplements_store_preloader_bg_color', array(
	    'default' => '#fff',
	    'sanitize_callback' => 'sanitize_hex_color'
  	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'medical_supplements_store_preloader_bg_color', array(
  		'label' => 'Preloader Background Color',
	    'section' => 'medical_supplements_store_left_right',
	    'settings' => 'medical_supplements_store_preloader_bg_color',
  	)));

	$wp_customize->add_setting('medical_supplements_store_width_options',array(
        'default' => 'Full Layout',
        'sanitize_callback' => 'medical_supplements_store_sanitize_choices'
	));
	$wp_customize->add_control('medical_supplements_store_width_options',array(
        'type' => 'select',
        'label' => __('Select Site Layout','medical-supplements-store'),
        'section' => 'medical_supplements_store_left_right',
        'choices' => array(
            'Full Layout' => __('Full Layout','medical-supplements-store'),
            'Contained Layout' => __('Contained Layout','medical-supplements-store'),
            'Boxed Layout' => __('Boxed Layout','medical-supplements-store'),
        ),
	) );

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('medical_supplements_store_theme_options',array(
	        'default' => 'Right Sidebar',
	        'sanitize_callback' => 'medical_supplements_store_sanitize_choices'
	) );
	$wp_customize->add_control('medical_supplements_store_theme_options',
	    array(
	        'type' => 'radio',
	        'label' => __( 'Sidebar Options', 'medical-supplements-store' ),
	        'section' => 'medical_supplements_store_left_right',
	        'choices' => array(
	            'Left Sidebar' => __('Left Sidebar','medical-supplements-store'),
	            'Right Sidebar' => __('Right Sidebar','medical-supplements-store'),
	            'One Column' => __('One Column','medical-supplements-store'),
	            'Three Columns' => __('Three Columns','medical-supplements-store'),
	            'Four Columns' => __('Four Columns','medical-supplements-store'),
	            'Grid Layout' => __('Grid Layout','medical-supplements-store')
	        ),
	    )
    );

    //topbar
	$wp_customize->add_section('medical_supplements_store_topbar',array(
		'title'	=> __('Top Header','medical-supplements-store'),
		'description'	=> __('Add Header Content here','medical-supplements-store'),
		'priority'	=> null,
		'panel' => 'medical_supplements_store_panel_id',
	));

	//Show /Hide Topbar
	$wp_customize->add_setting( 'medical_supplements_store_topbar_hide',array(
		'default' => false,
      	'sanitize_callback'	=> 'medical_supplements_store_sanitize_checkbox'
    ) );
    $wp_customize->add_control('medical_supplements_store_topbar_hide',array(
    	'type' => 'checkbox',
        'label' => __( 'Show / Hide Topbar','medical-supplements-store' ),
        'section' => 'medical_supplements_store_topbar'
    ));

	$wp_customize->add_setting('medical_supplements_store_topbar_top_bottom',array(
		'default'=> '10',
		'sanitize_callback'	=> 'medical_supplements_store_sanitize_float'
	));
	$wp_customize->add_control('medical_supplements_store_topbar_top_bottom',array(
		'label'	=> __('Topbar Top Bottom Padding','medical-supplements-store'),
		'input_attrs' => array(
            'step' => 1,
			'min'  => 0,
			'max'  => 50,
        ),
		'section'=> 'medical_supplements_store_topbar',
		'type'=> 'number',
	));

	//Sticky Header
	$wp_customize->add_setting( 'medical_supplements_store_sticky_header',array(
      	'sanitize_callback'	=> 'medical_supplements_store_sanitize_checkbox'
    ) );
    $wp_customize->add_control('medical_supplements_store_sticky_header',array(
    	'type' => 'checkbox',
        'label' => __( 'Sticky Header','medical-supplements-store' ),
        'section' => 'medical_supplements_store_topbar'
    ));

    $wp_customize->add_setting('medical_supplements_store_sticky_header_padding', array(
		'default'=> '',
		'sanitize_callback'	=> 'medical_supplements_store_sanitize_float'
	));
	$wp_customize->add_control('medical_supplements_store_sticky_header_padding', array(
		'label'	=> __('Sticky Header Padding','medical-supplements-store'),
		'input_attrs' => array(
            'step' => 1,
			'min'  => 0,
			'max'  => 50,
        ),
		'section'=> 'medical_supplements_store_topbar',
		'type'=> 'number',
	));

	$wp_customize->selective_refresh->add_partial(
		'medical_supplements_store_world',
		array(
			'selector'        => '.topbox span',
			'render_callback' => 'medical_supplements_store_customize_partial_medical_supplements_store_world',
		)
	);

	$wp_customize->add_setting('medical_supplements_store_shipping_icon',array(
		'default'	=> 'fas fa-globe',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Medical_Supplements_Store_Icon_Changer(
        $wp_customize, 'medical_supplements_store_shipping_icon',array(
		'label'	=> __('Shipping Icon','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_topbar',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting('medical_supplements_store_world',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('medical_supplements_store_world',array(
		'label'	=> __('Shipping Text','medical-supplements-store'),
		'section' => 'medical_supplements_store_topbar',
		'setting' => 'medical_supplements_store_world',
		'type' => 'text'
	));

	$wp_customize->add_setting('medical_supplements_store_delivery_icon',array(
		'default'	=> 'fas fa-truck',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Medical_Supplements_Store_Icon_Changer(
        $wp_customize, 'medical_supplements_store_delivery_icon',array(
		'label'	=> __('Delivery Icon','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_topbar',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting('medical_supplements_store_free_shipping',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('medical_supplements_store_free_shipping',array(
		'label'	=> __('Delivery Text','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_topbar',
		'setting'	=> 'medical_supplements_store_free_shipping',
		'type'	=> 'text'
	));

	$wp_customize->add_setting('medical_supplements_store_navigation_case',array(
        'default' => 'capitalize',
        'sanitize_callback' => 'medical_supplements_store_sanitize_choices'
	));
	$wp_customize->add_control('medical_supplements_store_navigation_case',array(
        'type' => 'select',
        'label' => __('Navigation Case','medical-supplements-store'),
        'section' => 'medical_supplements_store_topbar',
        'choices' => array(
            'uppercase' => __('Uppercase','medical-supplements-store'),
            'capitalize' => __('Capitalize','medical-supplements-store'),
        ),
	) );

	$wp_customize->add_setting( 'medical_supplements_store_nav_font_size', array(
		'default'           => 14,
		'sanitize_callback' => 'medical_supplements_store_sanitize_float',
	) );
	$wp_customize->add_control( 'medical_supplements_store_nav_font_size', array(
		'label' => __( 'Navigation Font Size','medical-supplements-store' ),
		'section'     => 'medical_supplements_store_topbar',
		'type'        => 'number',
		'input_attrs' => array(
			'step' => 1,
			'min' => 0,
			'max' => 50,
		),
	) );

	$wp_customize->add_setting('medical_supplements_store_font_weight_menu_option',array(
        'default' => 'Default',
        'sanitize_callback' => 'medical_supplements_store_sanitize_choices'
    ));
    $wp_customize->add_control('medical_supplements_store_font_weight_menu_option',array(
        'type' => 'select',
        'label' => __('Navigation Font Weight','medical-supplements-store'),
        'section' => 'medical_supplements_store_topbar',
        'choices' => array(
            '100' => __('100','medical-supplements-store'),
            '200' => __('200','medical-supplements-store'),
            '300' => __('300','medical-supplements-store'),
            '400' => __('400','medical-supplements-store'),
            'Default' => __('500','medical-supplements-store'),
            '600' => __('600','medical-supplements-store'),
            '700' => __('700','medical-supplements-store'),
            '800' => __('800','medical-supplements-store'),
            '900' => __('900','medical-supplements-store'),
        ),
	) );

	//Social Icons(topbar)
	$wp_customize->add_section('medical_supplements_store_topbar_header',array(
		'title'	=> __('Social Icon Section','medical-supplements-store'),
		'description'	=> __('Add Header Content here','medical-supplements-store'),
		'priority'	=> null,
		'panel' => 'medical_supplements_store_panel_id',
	));

	$wp_customize->selective_refresh->add_partial(
		'medical_supplements_store_facebook_url',
		array(
			'selector'        => '.social',
			'render_callback' => 'medical_supplements_store_customize_partial_medical_supplements_store_facebook_url',
		)
	);

	$wp_customize->add_setting('medical_supplements_store_facebook_icon',array(
		'default'	=> 'fab fa-facebook-f',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Medical_Supplements_Store_Icon_Changer(
        $wp_customize, 'medical_supplements_store_facebook_icon',array(
		'label'	=> __('Facebook Icon','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_topbar_header',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('medical_supplements_store_facebook_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('medical_supplements_store_facebook_url',array(
		'label'	=> __('Add Facebook link','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_topbar_header',
		'setting'	=> 'medical_supplements_store_facebook_url',
		'type'	=> 'url'
	));

	$wp_customize->add_setting('medical_supplements_store_twitter_icon',array(
		'default'	=> 'fab fa-twitter',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Medical_Supplements_Store_Icon_Changer(
        $wp_customize, 'medical_supplements_store_twitter_icon',array(
		'label'	=> __('Twitter Icon','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_topbar_header',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('medical_supplements_store_twitter_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('medical_supplements_store_twitter_url',array(
		'label'	=> __('Add Twitter link','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_topbar_header',
		'setting'	=> 'medical_supplements_store_twitter_url',
		'type'	=> 'url'
	));

	$wp_customize->add_setting('medical_supplements_store_instagram_icon',array(
		'default'	=> 'fab fa-instagram',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Medical_Supplements_Store_Icon_Changer(
        $wp_customize, 'medical_supplements_store_instagram_icon',array(
		'label'	=> __('Instagram Icon','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_topbar_header',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('medical_supplements_store_insta_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));	
	$wp_customize->add_control('medical_supplements_store_insta_url',array(
		'label'	=> __('Add Instagram link','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_topbar_header',
		'setting'	=> 'medical_supplements_store_insta_url',
		'type'	=> 'url'
	));

	$wp_customize->add_setting('medical_supplements_store_linkedin_icon',array(
		'default'	=> 'fab fa-linkedin-in',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Medical_Supplements_Store_Icon_Changer(
        $wp_customize, 'medical_supplements_store_linkedin_icon',array(
		'label'	=> __('Linkedin Icon','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_topbar_header',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('medical_supplements_store_linkdin_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));	
	$wp_customize->add_control('medical_supplements_store_linkdin_url',array(
		'label'	=> __('Add Linkedin link','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_topbar_header',
		'setting'	=> 'medical_supplements_store_linkdin_url',
		'type'	=> 'url'
	));

	$wp_customize->add_setting('medical_supplements_store_youtube_icon',array(
		'default'	=> 'fab fa-youtube',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Medical_Supplements_Store_Icon_Changer(
        $wp_customize, 'medical_supplements_store_youtube_icon',array(
		'label'	=> __('Youtube Icon','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_topbar_header',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('medical_supplements_store_youtube_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('medical_supplements_store_youtube_url',array(
		'label'	=> __('Add Youtube link','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_topbar_header',
		'setting'	=> 'medical_supplements_store_youtube_url',
		'type'		=> 'url'
	));

	/*Social icon font size*/
	$wp_customize->add_setting('medical_supplements_store_social_icon_fontsize',array(
		'default'=> '',
		'sanitize_callback'	=> 'medical_supplements_store_sanitize_float'
	));
	$wp_customize->add_control('medical_supplements_store_social_icon_fontsize',array(
		'label'	=> __('Social Icons Font Size','medical-supplements-store'),
		'input_attrs' => array(
            'step' => 1,
			'min'  => 0,
			'max'  => 100,
        ),
		'section'=> 'medical_supplements_store_topbar_header',
		'type'=> 'number',
	));

	//home page slider
	$wp_customize->add_section( 'medical_supplements_store_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'medical-supplements-store' ),
		'priority'   => null,
		'panel' => 'medical_supplements_store_panel_id'
	) );

	$wp_customize->selective_refresh->add_partial(
		'medical_supplements_store_slider_arrows',
		array(
			'selector'        => '#slider .inner_carousel h1',
			'render_callback' => 'medical_supplements_store_customize_partial_medical_supplements_store_slider_arrows',
		)
	);

	$wp_customize->add_setting('medical_supplements_store_slider_arrows',array(
      	'default' => false,
      	'sanitize_callback'	=> 'medical_supplements_store_sanitize_checkbox'
	));
	$wp_customize->add_control('medical_supplements_store_slider_arrows',array(
	    'type' => 'checkbox',
	    'label' => __('Show / Hide slider','medical-supplements-store'),
	    'section' => 'medical_supplements_store_slidersettings',
	));

	for ( $count = 1; $count <= 4; $count++ ) {
		$wp_customize->add_setting( 'medical_supplements_store_slidersettings_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'medical_supplements_store_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'medical_supplements_store_slidersettings_page' . $count, array(
			'label'    => __( 'Select Slide Image Page', 'medical-supplements-store' ),
			'section'  => 'medical_supplements_store_slidersettings',
			'type'     => 'dropdown-pages'
		) );
	}

	$wp_customize->add_setting('medical_supplements_store_slider_title',array(
       'default' => true,
       'sanitize_callback'	=> 'medical_supplements_store_sanitize_checkbox'
	));
	$wp_customize->add_control('medical_supplements_store_slider_title',array(
	   'type' => 'checkbox',
	   'label' => __('Show / Hide slider Title','medical-supplements-store'),
	   'section' => 'medical_supplements_store_slidersettings',
	));

	$wp_customize->add_setting('medical_supplements_store_home_slider_overlay',array(
       'default' => true,
       'sanitize_callback'	=> 'medical_supplements_store_sanitize_checkbox'
    ));
    $wp_customize->add_control('medical_supplements_store_home_slider_overlay',array(
       'type' => 'checkbox',
       'label' => __('Slider Overlay','medical-supplements-store'),
		'description'    => __('This option will add colors over the slider.','medical-supplements-store'),
       'section' => 'medical_supplements_store_slidersettings'
    ));

    $wp_customize->add_setting('medical_supplements_store_home_slider_overlay_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'medical_supplements_store_home_slider_overlay_color', array(
		'label'    => __('Slider Overlay Color', 'medical-supplements-store'),
		'section'  => 'medical_supplements_store_slidersettings',
		'settings' => 'medical_supplements_store_home_slider_overlay_color',
	)));

	//Opacity
	$wp_customize->add_setting('medical_supplements_store_slider_opacity',array(
        'default'   => 0.7,
        'sanitize_callback' => 'medical_supplements_store_sanitize_choices'
	));
	$wp_customize->add_control( 'medical_supplements_store_slider_opacity', array(
		'label'       => esc_html__( 'Slider Image Opacity','medical-supplements-store' ),
		'section'    => 'medical_supplements_store_slidersettings',
		'type'        => 'select',
		'settings'   => 'medical_supplements_store_slider_opacity',
		'choices' => array(
	      '0' =>  esc_attr('0','medical-supplements-store'),
	      '0.1' =>  esc_attr('0.1','medical-supplements-store'),
	      '0.2' =>  esc_attr('0.2','medical-supplements-store'),
	      '0.3' =>  esc_attr('0.3','medical-supplements-store'),
	      '0.4' =>  esc_attr('0.4','medical-supplements-store'),
	      '0.5' =>  esc_attr('0.5','medical-supplements-store'),
	      '0.6' =>  esc_attr('0.6','medical-supplements-store'),
	      '0.7' =>  esc_attr('0.7','medical-supplements-store'),
	      '0.8' =>  esc_attr('0.8','medical-supplements-store'),
	      '0.9' =>  esc_attr('0.9','medical-supplements-store')
	  ),
	));

	//content Alignment
    $wp_customize->add_setting('medical_supplements_store_slider_content_option',array(
    	'default' => 'Left',
        'sanitize_callback' => 'medical_supplements_store_sanitize_choices'
	));
	$wp_customize->add_control('medical_supplements_store_slider_content_option',array(
        'type' => 'select',
        'label' => __('Slider Content Alignment','medical-supplements-store'),
        'section' => 'medical_supplements_store_slidersettings',
        'choices' => array(
            'Center' => __('Center','medical-supplements-store'),
            'Left' => __('Left','medical-supplements-store'),
            'Right' => __('Right','medical-supplements-store'),
        ),
	) );

	$wp_customize->add_setting('medical_supplements_store_content_spacing',array(
		'sanitize_callback'	=> 'esc_html'
	));
	$wp_customize->add_control('medical_supplements_store_content_spacing',array(
		'label'	=> esc_html__('Slider Content Spacing','medical-supplements-store'),
		'section'=> 'medical_supplements_store_slidersettings',
	));

	$wp_customize->add_setting( 'medical_supplements_store_slider_top_spacing', array(
		'default'  => '',
		'sanitize_callback'	=> 'medical_supplements_store_sanitize_float'
	) );
	$wp_customize->add_control( 'medical_supplements_store_slider_top_spacing', array(
		'label' => esc_html__( 'Top','medical-supplements-store' ),
		'section' => 'medical_supplements_store_slidersettings',
		'type'  => 'number',
		'input_attrs' => array(
			'step' => 1,
			'min' => 0,
			'max' => 100,
		),
	) );

	$wp_customize->add_setting( 'medical_supplements_store_slider_bottom_spacing', array(
		'default'  => '',
		'sanitize_callback'	=> 'medical_supplements_store_sanitize_float'
	) );
	$wp_customize->add_control( 'medical_supplements_store_slider_bottom_spacing', array(
		'label' => esc_html__( 'Bottom','medical-supplements-store' ),
		'section' => 'medical_supplements_store_slidersettings',
		'type'  => 'number',
		'input_attrs' => array(
			'step' => 1,
			'min' => 0,
			'max' => 100,
		),
	) );

	$wp_customize->add_setting( 'medical_supplements_store_slider_left_spacing', array(
		'default'  => '',
		'sanitize_callback'	=> 'medical_supplements_store_sanitize_float'
	) );
	$wp_customize->add_control( 'medical_supplements_store_slider_left_spacing', array(
		'label' => esc_html__( 'Left','medical-supplements-store'),
		'section' => 'medical_supplements_store_slidersettings',
		'type'  => 'number',
		'input_attrs' => array(
			'step' => 1,
			'min' => 0,
			'max' => 100,
		),
	) );

	$wp_customize->add_setting( 'medical_supplements_store_slider_right_spacing', array(
		'default'  => '',
		'sanitize_callback'	=> 'medical_supplements_store_sanitize_float'
	) );
	$wp_customize->add_control( 'medical_supplements_store_slider_right_spacing', array(
		'label' => esc_html__('Right','medical-supplements-store'),
		'section' => 'medical_supplements_store_slidersettings',
		'type'  => 'number',
		'input_attrs' => array(
			'step' => 1,
			'min' => 0,
			'max' => 100,
		),
	) );

	$wp_customize->add_setting( 'medical_supplements_store_slider_speed', array(
		'default'  => 3000,
		'sanitize_callback'	=> 'medical_supplements_store_sanitize_float'
	) );
	$wp_customize->add_control( 'medical_supplements_store_slider_speed', array(
		'label' => esc_html__('Slider Speed','medical-supplements-store'),
		'section' => 'medical_supplements_store_slidersettings',
		'type'  => 'number',
		'input_attrs' => array(
			'step' => 500,
			'min' => 500,
			'max' => 5000,
		),
	) );
	$wp_customize->add_setting( 'medical_supplements_store_slider_height', array(
		'default'  => ' ',
		'sanitize_callback'	=> 'medical_supplements_store_sanitize_float'
	) );
	$wp_customize->add_control( 'medical_supplements_store_slider_height', array(
		'label' => esc_html__('Slider Height','medical-supplements-store'),
		'section' => 'medical_supplements_store_slidersettings',
		'type'  => 'number',
		'input_attrs' => array(
			'step' => 5,
			'min' => 500,
			'max' => 1000,
		),
	) );


	// Service Section
	$wp_customize->add_section('medical_supplements_store_services',array(
		'title'	=> __('Services Section','medical-supplements-store'),
		'description'	=> __('Add services Content here','medical-supplements-store'),
		'priority'	=> null,
		'panel' => 'medical_supplements_store_panel_id',
	));

	$wp_customize->selective_refresh->add_partial(
		'medical_supplements_store_delivery',
		array(
			'selector'        => '#custom-page-services strong',
			'render_callback' => 'medical_supplements_store_customize_partial_medical_supplements_store_delivery',
		)
	);

    $wp_customize->add_setting('medical_supplements_store_delivery',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('medical_supplements_store_delivery',array(
		'label'	=> __('Free Delivery','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_services',
		'setting'	=> 'medical_supplements_store_delivery',
		'type'	=> 'text'
	));

    $wp_customize->add_setting('medical_supplements_store_delivery_line',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('medical_supplements_store_delivery_line',array(
		'label'	=> __('Delivery Text','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_services',
		'setting'	=> 'medical_supplements_store_delivery_line',
		'type'	=> 'text'
	));

	$wp_customize->add_setting('medical_supplements_store_return',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('medical_supplements_store_return',array(
		'label'	=> __('Return','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_services',
		'setting'	=> 'medical_supplements_store_return',
		'type'	=> 'text'
	));

    $wp_customize->add_setting('medical_supplements_store_return_line',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('medical_supplements_store_return_line',array(
		'label'	=> __('Return Text','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_services',
		'setting'	=> 'medical_supplements_store_return_line',
		'type'	=> 'text'
	));

	$wp_customize->add_setting('medical_supplements_store_satisfy',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('medical_supplements_store_satisfy',array(
		'label'	=> __('Satisfaction','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_services',
		'setting'	=> 'medical_supplements_store_satisfy',
		'type'	=> 'text'
	));

    $wp_customize->add_setting('medical_supplements_store_satisfy_line',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('medical_supplements_store_satisfy_line',array(
		'label'	=> __('Satisfaction Text','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_services',
		'setting'	=> 'medical_supplements_store_satisfy_line',
		'type'	=> 'text'
	));

	$wp_customize->add_setting('medical_supplements_store_points',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('medical_supplements_store_points',array(
		'label'	=> __('Loyalty','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_services',
		'setting'	=> 'medical_supplements_store_points',
		'type'	=> 'text'
	));

    $wp_customize->add_setting('medical_supplements_store_points_line',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('medical_supplements_store_points_line',array(
		'label'	=> __('Loyalty Text','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_services',
		'setting'	=> 'medical_supplements_store_points_line',
		'type'	=> 'text'
	));

	//Our Product
	$wp_customize->add_section('medical_supplements_store_product',array(
		'title'	=> __('Best Sellers','medical-supplements-store'),
		'description'=> __('This section will appear below the slider.','medical-supplements-store'),
		'panel' => 'medical_supplements_store_panel_id',
	));

	$wp_customize->selective_refresh->add_partial(
		'medical_supplements_store_sec1_title',
		array(
			'selector'        => '#our-products strong',
			'render_callback' => 'medical_supplements_store_customize_partial_medical_supplements_store_sec1_title',
		)
	);

	$wp_customize->add_setting('medical_supplements_store_sec1_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('medical_supplements_store_sec1_title',array(
		'label'	=> __('Section Title','medical-supplements-store'),
		'section'=> 'medical_supplements_store_product',
		'setting'=> 'medical_supplements_store_sec1_title',
		'type'=> 'text'
	));	

	$wp_customize->add_setting( 'medical_supplements_store_product_page', array(
		'default'           => '',
		'sanitize_callback' => 'medical_supplements_store_sanitize_dropdown_pages'
	));
	$wp_customize->add_control( 'medical_supplements_store_product_page', array(
		'label'    => __( 'Select Product Page', 'medical-supplements-store' ),
		'section'  => 'medical_supplements_store_product',
		'type'     => 'dropdown-pages'
	));

	//Blog Post
	$wp_customize->add_section('medical_supplements_store_blog_post',array(
		'title'	=> __('Post Settings','medical-supplements-store'),
		'panel' => 'medical_supplements_store_panel_id',
	));	

	$wp_customize->add_setting('medical_supplements_store_date_hide',array(
       'default' => 'false',
       'sanitize_callback'	=> 'medical_supplements_store_sanitize_checkbox'
    ));
    $wp_customize->add_control('medical_supplements_store_date_hide',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Post Date','medical-supplements-store'),
       'section' => 'medical_supplements_store_blog_post'
    ));

    $wp_customize->add_setting('medical_supplements_store_author_hide',array(
       'default' => 'false',
       'sanitize_callback'	=> 'medical_supplements_store_sanitize_checkbox'
    ));
    $wp_customize->add_control('medical_supplements_store_author_hide',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Post Author','medical-supplements-store'),
       'section' => 'medical_supplements_store_blog_post'
    ));

    $wp_customize->add_setting('medical_supplements_store_comment_hide',array(
       'default' => 'false',
       'sanitize_callback'	=> 'medical_supplements_store_sanitize_checkbox'
    ));
    $wp_customize->add_control('medical_supplements_store_comment_hide',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Post Comments','medical-supplements-store'),
       'section' => 'medical_supplements_store_blog_post'
    ));

    $wp_customize->add_setting('medical_supplements_store_time_hide',array(
       'default' => false,
       'sanitize_callback'	=> 'medical_supplements_store_sanitize_checkbox'
    ));
    $wp_customize->add_control('medical_supplements_store_time_hide',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Post Time','medical-supplements-store'),
       'section' => 'medical_supplements_store_blog_post'
    ));

    $wp_customize->add_setting('medical_supplements_store_feature_image_hide',array(
       'default' => true,
       'sanitize_callback'	=> 'medical_supplements_store_sanitize_checkbox'
    ));
    $wp_customize->add_control('medical_supplements_store_feature_image_hide',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Featured Image','medical-supplements-store'),
       'section' => 'medical_supplements_store_blog_post'
    ));

    $wp_customize->add_setting( 'medical_supplements_store_featured_image_border_radius', array(
		'default' => 0,
		'sanitize_callback'	=> 'medical_supplements_store_sanitize_float'
	) );
	$wp_customize->add_control( 'medical_supplements_store_featured_image_border_radius', array(
		'label' => __( 'Featured image border radius','medical-supplements-store' ),
		'section' => 'medical_supplements_store_blog_post',
		'type'  => 'number',
		'input_attrs' => array(
			'step' => 1,
			'min'  => 0,
			'max'  => 50,
		),
	) );

    $wp_customize->add_setting( 'medical_supplements_store_featured_image_box_shadow', array(
		'default' => 0,
		'sanitize_callback'	=> 'medical_supplements_store_sanitize_float'
	) );
	$wp_customize->add_control( 'medical_supplements_store_featured_image_box_shadow', array(
		'label' => __( 'Featured image box shadow','medical-supplements-store' ),
		'section' => 'medical_supplements_store_blog_post',
		'type'  => 'number',
		'input_attrs' => array(
			'step' => 1,
			'min'  => 0,
			'max'  => 50,
		),
	) );

    $wp_customize->add_setting('medical_supplements_store_post_content',array(
    	'default' => 'Excerpt Content',
        'sanitize_callback' => 'medical_supplements_store_sanitize_choices'
	));
	$wp_customize->add_control('medical_supplements_store_post_content',array(
        'type' => 'radio',
        'label' => __('Post Content Type','medical-supplements-store'),
        'section' => 'medical_supplements_store_blog_post',
        'choices' => array(
            'No Content' => __('No Content','medical-supplements-store'),
            'Full Content' => __('Full Content','medical-supplements-store'),
            'Excerpt Content' => __('Excerpt Content','medical-supplements-store'),
        ),
	) );

    $wp_customize->add_setting( 'medical_supplements_store_post_excerpt_length', array(
		'default'              => 20,
		'sanitize_callback'	=> 'medical_supplements_store_sanitize_float'
	) );
	$wp_customize->add_control( 'medical_supplements_store_post_excerpt_length', array(
		'label' => esc_html__( 'Post Excerpt Length','medical-supplements-store' ),
		'section'  => 'medical_supplements_store_blog_post',
		'type'  => 'number',
		'settings' => 'medical_supplements_store_post_excerpt_length',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting( 'medical_supplements_store_button_excerpt_suffix', array(
		'default'   => '[...]',
		'sanitize_callback'	=> 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'medical_supplements_store_button_excerpt_suffix', array(
		'label'       => esc_html__( 'Excerpt Suffix','medical-supplements-store' ),
		'section'     => 'medical_supplements_store_blog_post',
		'type'        => 'text',
		'settings' => 'medical_supplements_store_button_excerpt_suffix'
	) );

	$wp_customize->add_setting( 'medical_supplements_store_post_button_text', array(
		'default'   => __('Read More','medical-supplements-store' ),
		'sanitize_callback'	=> 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'medical_supplements_store_post_button_text', array(
		'label' => esc_html__('Post Button Text','medical-supplements-store' ),
		'section'     => 'medical_supplements_store_blog_post',
		'type'        => 'text',
		'settings'    => 'medical_supplements_store_post_button_text'
	) );

	$wp_customize->add_setting('medical_supplements_store_top_button_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'medical_supplements_store_sanitize_float'
	));
	$wp_customize->add_control('medical_supplements_store_top_button_padding',array(
		'label'	=> __('Top Bottom Button Padding','medical-supplements-store'),
		'input_attrs' => array(
            'step' => 1,
			'min'  => 0,
			'max'  => 50,
        ),
		'section'=> 'medical_supplements_store_blog_post',
		'type'=> 'number',
	));

	$wp_customize->add_setting('medical_supplements_store_left_button_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'medical_supplements_store_sanitize_float'
	));
	$wp_customize->add_control('medical_supplements_store_left_button_padding',array(
		'label'	=> __('Left Right Button Padding','medical-supplements-store'),
		'input_attrs' => array(
            'step'             => 1,
			'min'              => 0,
			'max'              => 50,
        ),
		'section'=> 'medical_supplements_store_blog_post',
		'type'=> 'number',
	));

	$wp_customize->add_setting( 'medical_supplements_store_button_border_radius', array(
		'default'=> '0',
		'sanitize_callback'	=> 'medical_supplements_store_sanitize_float'
	) );
	$wp_customize->add_control('medical_supplements_store_button_border_radius', array(
        'label'  => __('Button Border Radius','medical-supplements-store'),
        'type'=> 'number',
        'section'  => 'medical_supplements_store_blog_post',
        'input_attrs' => array(
        	'step' => 1,
            'min' => 0,
            'max' => 50,
        ),
    ));

	$wp_customize->add_setting( 'medical_supplements_store_post_blocks', array(
        'default'			=> 'Within box',
        'sanitize_callback'	=> 'medical_supplements_store_sanitize_choices'
    ));
    $wp_customize->add_control( 'medical_supplements_store_post_blocks', array(
        'section' => 'medical_supplements_store_blog_post',
        'type' => 'select',
        'label' => __( 'Post blocks', 'medical-supplements-store' ),
        'choices' => array(
            'Within box'  => __( 'Within box', 'medical-supplements-store' ),
            'Without box' => __( 'Without box', 'medical-supplements-store' ),
    )));

    $wp_customize->add_setting('medical_supplements_store_navigation_hide',array(
       'default' => true,
       'sanitize_callback'	=> 'medical_supplements_store_sanitize_checkbox'
    ));
    $wp_customize->add_control('medical_supplements_store_navigation_hide',array(
		'section' => 'medical_supplements_store_blog_post' ,
       'type' => 'checkbox',
       'label' => __('Enable / Disable Post Navigation','medical-supplements-store'),
    ));

    $wp_customize->add_setting( 'medical_supplements_store_post_navigation_type', array(
        'default'			=> 'numbers',
        'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control( 'medical_supplements_store_post_navigation_type', array(
        'section' => 'medical_supplements_store_blog_post',
        'type' => 'select',
        'label' => __( 'Post Navigation Type', 'medical-supplements-store' ),
        'choices'		=> array(
            'numbers'  => __( 'Number', 'medical-supplements-store' ),
            'next-prev' => __( 'Next/Prev Button', 'medical-supplements-store' ),
    )));

    $wp_customize->add_setting( 'medical_supplements_store_post_navigation_position', array(
        'default'			=> 'bottom',
        'sanitize_callback'	=> 'medical_supplements_store_sanitize_choices'
    ));
    $wp_customize->add_control( 'medical_supplements_store_post_navigation_position', array(
        'section' => 'medical_supplements_store_blog_post',
        'type' => 'select',
        'label' => __( 'Post Navigation Position', 'medical-supplements-store' ),
        'choices' => array(
            'top'  => __( 'Top', 'medical-supplements-store' ),
            'bottom' => __( 'Bottom', 'medical-supplements-store' ),
            'both' => __( 'Both', 'medical-supplements-store' ),
    )));

    //Single Post Settings
	$wp_customize->add_section('medical_supplements_store_single_post',array(
		'title'	=> __('Single Post Settings','medical-supplements-store'),
		'panel' => 'medical_supplements_store_panel_id',
	));	

	$wp_customize->add_setting('medical_supplements_store_feature_image',array(
       'default' => true,
       'sanitize_callback'	=> 'medical_supplements_store_sanitize_checkbox'
    ));
    $wp_customize->add_control('medical_supplements_store_feature_image',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Feature Image','medical-supplements-store'),
       'section' => 'medical_supplements_store_single_post'
    ));

    $wp_customize->add_setting('medical_supplements_store_tags',array(
       'default' => true,
       'sanitize_callback'	=> 'medical_supplements_store_sanitize_checkbox'
    ));
    $wp_customize->add_control('medical_supplements_store_tags',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Tags','medical-supplements-store'),
       'section' => 'medical_supplements_store_single_post'
    ));

    $wp_customize->add_setting('medical_supplements_store_comment',array(
       'default' => true,
       'sanitize_callback'	=> 'medical_supplements_store_sanitize_checkbox'
    ));
    $wp_customize->add_control('medical_supplements_store_comment',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Comment','medical-supplements-store'),
       'section' => 'medical_supplements_store_single_post'
    ));

    $wp_customize->add_setting('medical_supplements_store_single_post_time_hide',array(
       'default' => false,
       'sanitize_callback'	=> 'medical_supplements_store_sanitize_checkbox'
    ));
    $wp_customize->add_control('medical_supplements_store_single_post_time_hide',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Time','medical-supplements-store'),
       'section' => 'medical_supplements_store_single_post'
    ));

    $wp_customize->add_setting( 'medical_supplements_store_comment_width', array(
		'default' => 100,
		'sanitize_callback'	=> 'medical_supplements_store_sanitize_float'
	) );
	$wp_customize->add_control( 'medical_supplements_store_comment_width', array(
		'label' => __( 'Comment Textarea Width', 'medical-supplements-store'),
		'section' => 'medical_supplements_store_single_post',
		'type' => 'number',
		'settings' => 'medical_supplements_store_comment_width',
		'input_attrs' => array(
			'step' => 1,
			'min' => 0,
			'max' => 100,
		),
	) );

    $wp_customize->add_setting('medical_supplements_store_comment_title',array(
       'default' => __('Leave a Reply','medical-supplements-store' ),
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('medical_supplements_store_comment_title',array(
       'type' => 'text',
       'label' => __('Comment form Title','medical-supplements-store'),
       'section' => 'medical_supplements_store_single_post'
    ));

    $wp_customize->add_setting('medical_supplements_store_comment_submit_text',array(
       'default' => __('Post Comment','medical-supplements-store' ),
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('medical_supplements_store_comment_submit_text',array(
       'type' => 'text',
       'label' => __('Comment Button Text','medical-supplements-store'),
       'section' => 'medical_supplements_store_single_post'
    ));

    $wp_customize->add_setting('medical_supplements_store_nav_links',array(
       'default' => true,
       'sanitize_callback'	=> 'medical_supplements_store_sanitize_checkbox'
    ));
    $wp_customize->add_control('medical_supplements_store_nav_links',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Nav Links','medical-supplements-store'),
       'section' => 'medical_supplements_store_single_post'
    ));

    $wp_customize->add_setting('medical_supplements_store_prev_text',array(
       'default' => '',
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('medical_supplements_store_prev_text',array(
       'type' => 'text',
       'label' => __('Previous Navigation Text','medical-supplements-store'),
       'section' => 'medical_supplements_store_single_post'
    ));

    $wp_customize->add_setting('medical_supplements_store_next_text',array(
       'default' => '',
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('medical_supplements_store_next_text',array(
       'type' => 'text',
       'label' => __('Next Navigation Text','medical-supplements-store'),
       'section' => 'medical_supplements_store_single_post'
    ));

    $wp_customize->add_setting('medical_supplements_store_related_posts',array(
       'default' => true,
       'sanitize_callback'	=> 'medical_supplements_store_sanitize_checkbox'
    ));
    $wp_customize->add_control('medical_supplements_store_related_posts',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Related Posts','medical-supplements-store'),
       'section' => 'medical_supplements_store_single_post'
    ));

    $wp_customize->add_setting('medical_supplements_store_related_posts_title',array(
       'default' => '',
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('medical_supplements_store_related_posts_title',array(
       'type' => 'text',
       'label' => __('Related Posts Title','medical-supplements-store'),
       'section' => 'medical_supplements_store_single_post'
    ));

    $wp_customize->add_setting( 'medical_supplements_store_related_post_count', array(
		'default' => 3,
		'sanitize_callback'	=> 'medical_supplements_store_sanitize_float'
	) );
	$wp_customize->add_control( 'medical_supplements_store_related_post_count', array(
		'label' => esc_html__( 'Related Posts Count','medical-supplements-store' ),
		'section' => 'medical_supplements_store_single_post',
		'type' => 'number',
		'settings' => 'medical_supplements_store_related_post_count',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 0,
			'max'              => 6,
		),
	) );

    $wp_customize->add_setting( 'medical_supplements_store_post_order', array(
        'default' => 'categories',
        'sanitize_callback'	=> 'medical_supplements_store_sanitize_choices'
    ));
    $wp_customize->add_control( 'medical_supplements_store_post_order', array(
        'section' => 'medical_supplements_store_single_post',
        'type' => 'radio',
        'label' => __( 'Related Posts Order By', 'medical-supplements-store' ),
        'choices' => array(
            'categories'  => __('Categories', 'medical-supplements-store'),
            'tags' => __( 'Tags', 'medical-supplements-store' ),
    )));

    //404 page settings
	$wp_customize->add_section('medical_supplements_store_404_page',array(
		'title'	=> __('404 & No Result Page Settings','medical-supplements-store'),
		'priority'	=> null,
		'panel' => 'medical_supplements_store_panel_id',
	));

	$wp_customize->add_setting('medical_supplements_store_404_title',array(
       'default' => '',
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('medical_supplements_store_404_title',array(
       'type' => 'text',
       'label' => __('404 Page Title','medical-supplements-store'),
       'section' => 'medical_supplements_store_404_page'
    ));

    $wp_customize->add_setting('medical_supplements_store_404_text',array(
       'default' => '',
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('medical_supplements_store_404_text',array(
       'type' => 'text',
       'label' => __('404 Page Text','medical-supplements-store'),
       'section' => 'medical_supplements_store_404_page'
    ));

    $wp_customize->add_setting('medical_supplements_store_404_button_text',array(
       'default' => '',
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('medical_supplements_store_404_button_text',array(
       'type' => 'text',
       'label' => __('404 Page Button Text','medical-supplements-store'),
       'section' => 'medical_supplements_store_404_page'
    ));

    $wp_customize->add_setting('medical_supplements_store_no_result_title',array(
       'default' => '',
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('medical_supplements_store_no_result_title',array(
       'type' => 'text',
       'label' => __('No Result Page Title','medical-supplements-store'),
       'section' => 'medical_supplements_store_404_page'
    ));

    $wp_customize->add_setting('medical_supplements_store_no_result_text',array(
       'default' => '',
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('medical_supplements_store_no_result_text',array(
       'type' => 'text',
       'label' => __('No Result Page Text','medical-supplements-store'),
       'section' => 'medical_supplements_store_404_page'
    ));

    $wp_customize->add_setting('medical_supplements_store_show_search_form',array(
        'default' => true,
        'sanitize_callback'	=> 'medical_supplements_store_sanitize_checkbox'
	));
	$wp_customize->add_control('medical_supplements_store_show_search_form',array(
     	'type' => 'checkbox',
      	'label' => __('Show/Hide Search Form','medical-supplements-store'),
      	'section' => 'medical_supplements_store_404_page',
	));

	//Footer
	$wp_customize->add_section('medical_supplements_store_footer_section',array(
		'title'	=> __('Footer Section','medical-supplements-store'),
		'description'	=> '',
		'priority'	=> null,
		'panel' => 'medical_supplements_store_panel_id',
	));

	$wp_customize->selective_refresh->add_partial(
		'medical_supplements_store_show_back_to_top',
		array(
			'selector'        => '.scrollup',
			'render_callback' => 'medical_supplements_store_customize_partial_medical_supplements_store_show_back_to_top',
		)
	);

	$wp_customize->add_setting('medical_supplements_store_show_back_to_top',array(
        'default' => 'true',
        'sanitize_callback'	=> 'medical_supplements_store_sanitize_checkbox'
	));
	$wp_customize->add_control('medical_supplements_store_show_back_to_top',array(
     	'type' => 'checkbox',
      	'label' => __('Show/Hide Back to Top Button','medical-supplements-store'),
      	'section' => 'medical_supplements_store_footer_section',
	));

	$wp_customize->add_setting('medical_supplements_store_back_to_top_icon',array(
		'default'	=> 'fas fa-arrow-up',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Medical_Supplements_Store_Icon_Changer(
        $wp_customize, 'medical_supplements_store_back_to_top_icon',array(
		'label'	=> __('Back to Top Icon','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_footer_section',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('medical_supplements_store_back_to_top_text',array(
		'default'	=> __('Back to Top','medical-supplements-store'),
		'sanitize_callback'	=> 'sanitize_text_field',
	));	
	$wp_customize->add_control('medical_supplements_store_back_to_top_text',array(
		'label'	=> __('Back to Top Button Text','medical-supplements-store'),
		'section' => 'medical_supplements_store_footer_section',
		'type' => 'text'
	));

	$wp_customize->add_setting('medical_supplements_store_back_to_top_alignment',array(
        'default' => 'Right',
        'sanitize_callback' => 'medical_supplements_store_sanitize_choices'
	));
	$wp_customize->add_control('medical_supplements_store_back_to_top_alignment',array(
        'type' => 'select',
        'label' => __('Back to Top Button Alignment','medical-supplements-store'),
        'section' => 'medical_supplements_store_footer_section',
        'choices' => array(
            'Left' => __('Left','medical-supplements-store'),
            'Right' => __('Right','medical-supplements-store'),
            'Center' => __('Center','medical-supplements-store'),
        ),
	) );

	$wp_customize->add_setting('medical_supplements_store_footer_background_color', array(
		'default'           => '#000',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'medical_supplements_store_footer_background_color', array(
		'label'    => __('Footer Background Color', 'medical-supplements-store'),
		'section'  => 'medical_supplements_store_footer_section',
	)));

	$wp_customize->add_setting('medical_supplements_store_footer_background_img',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw',
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'medical_supplements_store_footer_background_img',array(
        'label' => __('Footer Background Image','medical-supplements-store'),
        'section' => 'medical_supplements_store_footer_section'
	)));

	$wp_customize->add_setting('medical_supplements_store_footer_widget_layout',array(
        'default'           => '4',
        'sanitize_callback' => 'medical_supplements_store_sanitize_choices',
    ));
    $wp_customize->add_control('medical_supplements_store_footer_widget_layout',array(
        'type'        => 'radio',
        'label'       => __('Footer widget layout', 'medical-supplements-store'),
        'section'     => 'medical_supplements_store_footer_section',
        'description' => __('Select the number of widget areas you want in the footer. After that, go to Appearance > Widgets and add your widgets.', 'medical-supplements-store'),
        'choices' => array(
            '1'     => __('One', 'medical-supplements-store'),
            '2'     => __('Two', 'medical-supplements-store'),
            '3'     => __('Three', 'medical-supplements-store'),
            '4'     => __('Four', 'medical-supplements-store')
        ),
    ));

    $wp_customize->add_setting('medical_supplements_store_copyright_alignment',array(
        'default' => 'Center',
        'sanitize_callback' => 'medical_supplements_store_sanitize_choices'
	));
	$wp_customize->add_control('medical_supplements_store_copyright_alignment',array(
        'type' => 'select',
        'label' => __('Copyright Alignment','medical-supplements-store'),
        'section' => 'medical_supplements_store_footer_section',
        'choices' => array(
            'Left' => __('Left','medical-supplements-store'),
            'Right' => __('Right','medical-supplements-store'),
            'Center' => __('Center','medical-supplements-store'),
        ),
	) );

	$wp_customize->add_setting('medical_supplements_store_copyright_fontsize',array(
		'default'	=> 16,
		'sanitize_callback'	=> 'medical_supplements_store_sanitize_float',
	));	
	$wp_customize->add_control('medical_supplements_store_copyright_fontsize',array(
		'label'	=> __('Copyright Font Size','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_footer_section',
		'type'		=> 'number'
	));

	$wp_customize->add_setting('medical_supplements_store_copyright_top_bottom_padding',array(
		'default'	=> 15,
		'sanitize_callback'	=> 'medical_supplements_store_sanitize_float',
	));	
	$wp_customize->add_control('medical_supplements_store_copyright_top_bottom_padding',array(
		'label'	=> __('Copyright Top Bottom Padding','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_footer_section',
		'type'		=> 'number'
	));

    $wp_customize->selective_refresh->add_partial(
		'medical_supplements_store_footer_copy',
		array(
			'selector'        => '#footer p',
			'render_callback' => 'medical_supplements_store_customize_partial_medical_supplements_store_footer_copy',
		)
	);
	
	$wp_customize->add_setting('medical_supplements_store_footer_copy',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field',
	));
	$wp_customize->add_control('medical_supplements_store_footer_copy',array(
		'label'	=> __('Copyright Text','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_footer_section',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('medical_supplements_store_copyright_background_color', array(
		'default'           => '#b60000',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'medical_supplements_store_copyright_background_color', array(
		'label'    => __('Copyright Background Color', 'medical-supplements-store'),
		'section'  => 'medical_supplements_store_footer_section',
	)));   

	//Mobile Media Section
	$wp_customize->add_section( 'medical_supplements_store_mobile_media_options' , array(
    	'title'      => __( 'Mobile Media Options', 'medical-supplements-store' ),
		'priority'   => null,
		'panel' => 'medical_supplements_store_panel_id'
	) );

	$wp_customize->add_setting('medical_supplements_store_responsive_open_menu_icon',array(
		'default'	=> 'fas fa-bars',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Medical_Supplements_Store_Icon_Changer(
        $wp_customize, 'medical_supplements_store_responsive_open_menu_icon',array(
		'label'	=> __('Open Menu Icon','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_mobile_media_options',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('medical_supplements_store_responsive_close_menu_icon',array(
		'default'	=> 'fas fa-times',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Medical_Supplements_Store_Icon_Changer(
        $wp_customize, 'medical_supplements_store_responsive_close_menu_icon',array(
		'label'	=> __('Close Menu Icon','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_mobile_media_options',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'medical_supplements_store_responsive_topbar_hide',array(
		'default' => false,
      	'sanitize_callback'	=> 'medical_supplements_store_sanitize_checkbox'
    ) );
    $wp_customize->add_control('medical_supplements_store_responsive_topbar_hide',array(
    	'type' => 'checkbox',
        'label' => __( 'Show / Hide Topbar','medical-supplements-store' ),
        'section' => 'medical_supplements_store_mobile_media_options'
    ));

    $wp_customize->add_setting('medical_supplements_store_mobile_media_slider',array(
       'default' => false,
       'sanitize_callback'	=> 'medical_supplements_store_sanitize_checkbox'
    ));
    $wp_customize->add_control('medical_supplements_store_mobile_media_slider',array(
       'type' => 'checkbox',
       'label' => __('Show / Hide Slider','medical-supplements-store'),
       'section' => 'medical_supplements_store_mobile_media_options'
    ));

    $wp_customize->add_setting('medical_supplements_store_responsive_show_back_to_top',array(
        'default' => true,
        'sanitize_callback'	=> 'medical_supplements_store_sanitize_checkbox'
	));
	$wp_customize->add_control('medical_supplements_store_responsive_show_back_to_top',array(
     	'type' => 'checkbox',
      	'label' => __('Show / Hide Back to Top Button','medical-supplements-store'),
      	'section' => 'medical_supplements_store_mobile_media_options',
	));

	$wp_customize->add_setting( 'medical_supplements_store_responsive_preloader_hide',array(
		'default' => false,
      	'sanitize_callback'	=> 'medical_supplements_store_sanitize_checkbox'
    ) );
    $wp_customize->add_control('medical_supplements_store_responsive_preloader_hide',array(
    	'type' => 'checkbox',
        'label' => __( 'Show / Hide Preloader','medical-supplements-store' ),
        'section' => 'medical_supplements_store_mobile_media_options'
    ));

    $wp_customize->add_setting( 'medical_supplements_store_responsive_sticky_header',array(
		'default' => false,
      	'sanitize_callback'	=> 'medical_supplements_store_sanitize_checkbox'
    ) );
    $wp_customize->add_control('medical_supplements_store_responsive_sticky_header',array(
    	'type' => 'checkbox',
        'label' => __( 'Show / Hide Sticky header','medical-supplements-store' ),
        'section' => 'medical_supplements_store_mobile_media_options'
    ));

	//Woocommerce Section
	$wp_customize->add_section( 'medical_supplements_store_woocommerce_options' , array(
    	'title'      => __( 'Additional WooCommerce Options', 'medical-supplements-store' ),
		'priority'   => null,
		'panel' => 'medical_supplements_store_panel_id'
	) );

	// Product Columns
	$wp_customize->add_setting( 'medical_supplements_store_products_per_row' , array(
		'default'           => '3',
		'transport'         => 'refresh',
		'sanitize_callback' => 'medical_supplements_store_sanitize_choices',
	) );

	$wp_customize->add_control('medical_supplements_store_products_per_row', array(
		'label' => __( 'Product per row', 'medical-supplements-store' ),
		'section'  => 'medical_supplements_store_woocommerce_options',
		'type'     => 'select',
		'choices'  => array(
			'2' => '2',
			'3' => '3',
			'4' => '4',
		),
	) );

	$wp_customize->add_setting('medical_supplements_store_product_per_page',array(
		'default'	=> '9',
		'sanitize_callback'	=> 'medical_supplements_store_sanitize_float'
	));	
	$wp_customize->add_control('medical_supplements_store_product_per_page',array(
		'label'	=> __('Product per page','medical-supplements-store'),
		'section'	=> 'medical_supplements_store_woocommerce_options',
		'type'		=> 'number'
	));

	$wp_customize->add_setting('medical_supplements_store_shop_sidebar',array(
       'default' => true,
       'sanitize_callback'	=> 'medical_supplements_store_sanitize_checkbox'
    ));
    $wp_customize->add_control('medical_supplements_store_shop_sidebar',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Shop page sidebar','medical-supplements-store'),
       'section' => 'medical_supplements_store_woocommerce_options',
    ));

	$wp_customize->add_setting('medical_supplements_store_shop_page_pagination',array(
		'default' => true,
		'sanitize_callback'	=> 'medical_supplements_store_sanitize_checkbox'
	 ));
	 $wp_customize->add_control('medical_supplements_store_shop_page_pagination',array(
		'type' => 'checkbox',
		'label' => __('Enable / Disable Shop page pagination','medical-supplements-store'),
		'section' => 'medical_supplements_store_woocommerce_options',
	 ));
 
    $wp_customize->add_setting('medical_supplements_store_product_page_sidebar',array(
       'default' => true,
       'sanitize_callback'	=> 'medical_supplements_store_sanitize_checkbox'
    ));
    $wp_customize->add_control('medical_supplements_store_product_page_sidebar',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Product page sidebar','medical-supplements-store'),
       'section' => 'medical_supplements_store_woocommerce_options',
    ));

    $wp_customize->add_setting('medical_supplements_store_related_product',array(
       'default' => true,
       'sanitize_callback'	=> 'medical_supplements_store_sanitize_checkbox'
    ));
    $wp_customize->add_control('medical_supplements_store_related_product',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable Related product','medical-supplements-store'),
       'section' => 'medical_supplements_store_woocommerce_options',
    ));

	$wp_customize->add_setting( 'medical_supplements_store_woocommerce_button_padding_top',array(
		'default' => 15,
		'sanitize_callback' => 'medical_supplements_store_sanitize_float'
	));
	$wp_customize->add_control( 'medical_supplements_store_woocommerce_button_padding_top',	array(
		'label' => esc_html__( 'Button Top Bottom Padding','medical-supplements-store' ),
		'type' => 'number',
		'section' => 'medical_supplements_store_woocommerce_options',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	));

	$wp_customize->add_setting( 'medical_supplements_store_woocommerce_button_padding_right',array(
	 	'default' => 20,
	 	'sanitize_callback' => 'medical_supplements_store_sanitize_float'
	));
	$wp_customize->add_control('medical_supplements_store_woocommerce_button_padding_right',	array(
	 	'label' => esc_html__( 'Button Right Left Padding','medical-supplements-store' ),
		'type' => 'number',
		'section' => 'medical_supplements_store_woocommerce_options',
	 	'input_attrs' => array(
			'min' => 0,
			'max' => 50,
	 		'step' => 1,
		),
	));

	$wp_customize->add_setting( 'medical_supplements_store_woocommerce_button_border_radius',array(
		'default' => 0,
		'sanitize_callback' => 'medical_supplements_store_sanitize_float'
	));
	$wp_customize->add_control('medical_supplements_store_woocommerce_button_border_radius',array(
		'label' => esc_html__( 'Button Border Radius','medical-supplements-store' ),
		'type' => 'number',
		'section' => 'medical_supplements_store_woocommerce_options',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	));

    $wp_customize->add_setting('medical_supplements_store_woocommerce_product_border',array(
       'default' => false,
       'sanitize_callback'	=> 'medical_supplements_store_sanitize_checkbox'
    ));
    $wp_customize->add_control('medical_supplements_store_woocommerce_product_border',array(
       'type' => 'checkbox',
       'label' => __('Enable / Disable product border','medical-supplements-store'),
       'section' => 'medical_supplements_store_woocommerce_options',
    ));

	$wp_customize->add_setting( 'medical_supplements_store_woocommerce_product_padding_top',array(
		'default' => '',
		'sanitize_callback' => 'medical_supplements_store_sanitize_float'
	));
	$wp_customize->add_control('medical_supplements_store_woocommerce_product_padding_top', array(
		'label' => esc_html__( 'Product Top Bottom Padding','medical-supplements-store' ),
		'type' => 'number',
		'section' => 'medical_supplements_store_woocommerce_options',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	));

	$wp_customize->add_setting( 'medical_supplements_store_woocommerce_product_padding_right',array(
		'default' => '',
		'sanitize_callback' => 'medical_supplements_store_sanitize_float'
	));
	$wp_customize->add_control('medical_supplements_store_woocommerce_product_padding_right', array(
		'label' => esc_html__( 'Product Right Left Padding','medical-supplements-store' ),
		'type' => 'number',
		'section' => 'medical_supplements_store_woocommerce_options',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	));

	$wp_customize->add_setting( 'medical_supplements_store_woocommerce_product_border_radius',array(
		'default' => 0,
		'sanitize_callback' => 'medical_supplements_store_sanitize_float'
	));
	$wp_customize->add_control('medical_supplements_store_woocommerce_product_border_radius',array(
		'label' => esc_html__( 'Product Border Radius','medical-supplements-store' ),
		'type' => 'number',
		'section' => 'medical_supplements_store_woocommerce_options',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	));

	$wp_customize->add_setting( 'medical_supplements_store_woocommerce_product_box_shadow',array(
		'default' => 0,
		'sanitize_callback' => 'medical_supplements_store_sanitize_float'
	));
	$wp_customize->add_control( 'medical_supplements_store_woocommerce_product_box_shadow',array(
		'label' => esc_html__( 'Product Box Shadow','medical-supplements-store' ),
		'type' => 'number',
		'section' => 'medical_supplements_store_woocommerce_options',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	));	

	$wp_customize->add_setting('medical_supplements_store_sale_position',array(
        'default' => 'right',
        'sanitize_callback' => 'medical_supplements_store_sanitize_choices'
	));
	$wp_customize->add_control('medical_supplements_store_sale_position',array(
        'type' => 'select',
        'label' => __('Sale badge Position','medical-supplements-store'),
        'section' => 'medical_supplements_store_woocommerce_options',
        'choices' => array(
            'left' => __('Left','medical-supplements-store'),
            'right' => __('Right','medical-supplements-store'),
        ),
	) );

	$wp_customize->add_setting( 'medical_supplements_store_woocommerce_sale_top_padding',array(
		'default' => 0,
		'sanitize_callback' => 'medical_supplements_store_sanitize_float'
	));
	$wp_customize->add_control( 'medical_supplements_store_woocommerce_sale_top_padding',	array(
		'label' => esc_html__( 'Sale Top Bottom Padding','medical-supplements-store' ),
		'type' => 'number',
		'section' => 'medical_supplements_store_woocommerce_options',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	));

	$wp_customize->add_setting( 'medical_supplements_store_woocommerce_sale_left_padding',array(
	 	'default' => 0,
	 	'sanitize_callback' => 'medical_supplements_store_sanitize_float'
	));
	$wp_customize->add_control('medical_supplements_store_woocommerce_sale_left_padding',	array(
	 	'label' => esc_html__( 'Sale Right Left Padding','medical-supplements-store' ),
		'type' => 'number',
		'section' => 'medical_supplements_store_woocommerce_options',
	 	'input_attrs' => array(
			'min' => 0,
			'max' => 50,
	 		'step' => 1,
		),
	));

	$wp_customize->add_setting( 'medical_supplements_store_woocommerce_sale_border_radius',array(
		'default' => 50,
		'sanitize_callback' => 'medical_supplements_store_sanitize_float'
	));
	$wp_customize->add_control('medical_supplements_store_woocommerce_sale_border_radius',array(
		'label' => esc_html__( 'Sale Border Radius','medical-supplements-store' ),
		'type' => 'number',
		'section' => 'medical_supplements_store_woocommerce_options',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	));

	$wp_customize->add_setting( 'medical_supplements_store_product_sale_font_size',array(
		'default' => 16,
		'sanitize_callback' => 'medical_supplements_store_sanitize_float'
	));
	$wp_customize->add_control('medical_supplements_store_product_sale_font_size',array(
		'label' => esc_html__( 'Sale Font Size','medical-supplements-store' ),
		'type' => 'number',
		'section' => 'medical_supplements_store_woocommerce_options',
		'input_attrs' => array(
			'min' => 0,
			'max' => 50,
			'step' => 1,
		),
	));
}
add_action( 'customize_register', 'medical_supplements_store_customize_register' );

// logo resize
load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-width.php' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class Medical_Supplements_Store_Customizer_Upsell {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object $manager Customizer manager.
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . 'inc/supplement-customize-theme-info-main.php' );
		load_template( trailingslashit( get_template_directory() ) . 'inc/supplement-customize-upsell-section.php' );

		// Register custom section types.
		$manager->register_section_type( 'Medical_Supplements_Store_Customizer_Theme_Info_Main' );

		// Main Documentation Link In Customizer Root.
		$manager->add_section(
			new Medical_Supplements_Store_Customizer_Theme_Info_Main(
				$manager, 'medical-supplements-store-theme-info', array(
					'theme_info_title' => __( 'Medical Supplement', 'medical-supplements-store' ),
					'label_url'        => esc_url( 'https://themescaliber.com/demo/doc/free-medical-supplements/' ),
					'label_text'       => __( 'Documentation', 'medical-supplements-store' ),
				)
			)
		);

		// Frontpage Sections Upsell.
		$manager->add_section(
			new Medical_Supplements_Store_Customizer_Upsell_Section(
				$manager, 'medical-supplements-store-upsell-frontpage-sections', array(
					'panel'       => 'medical_supplements_store_panel_id',
					'priority'    => 500,
					'options'     => array(
						esc_html__( 'Workout Section', 'medical-supplements-store' ),
						esc_html__( 'New Arrivals section', 'medical-supplements-store' ),
						esc_html__( 'Gym Timming section', 'medical-supplements-store' ),
						esc_html__( 'Video Section', 'medical-supplements-store' ),
						esc_html__( 'Blog section', 'medical-supplements-store' ),
						esc_html__( 'Testimonials section', 'medical-supplements-store' ),
						esc_html__( 'Instagram Feed section', 'medical-supplements-store' ),
					),
					'button_url'  => esc_url( 'https://www.themescaliber.com/themes/premium-medical-supplements-wordpress-theme' ),
					'button_text' => esc_html__( 'View PRO version', 'medical-supplements-store' ),
				)
			)
		);
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'medical-supplements-store-upsell-js', trailingslashit( esc_url(get_template_directory_uri()) ) . 'inc/js/supplement-customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'medical-supplements-store-theme-info-style', trailingslashit( esc_url(get_template_directory_uri()) ) . 'inc/css/supplement-style.css' );
	}
}

Medical_Supplements_Store_Customizer_Upsell::get_instance();